﻿using System;
using System.Collections.Generic;
using System.Data;
using System.Diagnostics;
using System.Globalization;
using System.Reflection;
using System.Runtime.Serialization;
using System.ServiceModel;
using System.ServiceModel.Activation;
using System.ServiceModel.Web;
using System.Text;
using System.Web;
using Seven.Management.Business;
using Seven.Management.Globals;
using Seven.Management.Objects;
using Seven.Management.Printing;
using System.Data.SqlClient;

namespace Seven.Management
{
    [ServiceContract(Namespace = "SevenIPMWS")]
    [AspNetCompatibilityRequirements(RequirementsMode = AspNetCompatibilityRequirementsMode.Allowed)]
    public class Maestro
    {
        #region Seguridad

        [WebGet]
        [OperationContract]
        public string GetDatosCombo(int IdJuego, string LangCode)
        {
            try
            {
                return HTMLSelects.Datos(IdJuego);
            }
            catch (Exception ex)
            {
                #region Manejo de Errores (Administrador)

                var metodo = MethodBase.GetCurrentMethod().Name;
                var msgError = string.Format(MssgTrace.Trace_Message_Error, metodo, ex);
                LogGenie.ErrorLogSave(ex.Message, 16, msgError, System.Diagnostics.TraceEventType.Error);

                #endregion

                #region Manejo de Errores (Base de Datos)

                try
                {
                    var xException = new Excepcion
                    {
                        EventID = 0,
                        Priority = 16,
                        Severity = TraceEventType.Error,
                        Title = ex.Message,
                        Timestamp = DateTime.Now,
                        MachineName = Environment.MachineName,
                        AppDomainName = Environment.UserDomainName,
                        ProcessID = string.Empty,
                        ProcessName = Environment.CommandLine,
                        ThreadName = string.Empty,
                        Message = ex.ToString()
                    };

                    Logica logica = new Logica();
                    logica.DataBaseLogError(xException);
                }
                catch
                {
                }

                #endregion

                CultureInfo ciLocal = new CultureInfo(LangCode);
                return "<p class=\"SevenMsgError\"><b>" + L.LBL("LblGENWrongQuery") + ":</b></br> " + L.ERR(ex.Message).Replace("[", "").Replace("]", "") + "</p>";
            }
        }

        #endregion

        #region Log Sheet

        [WebGet]
        [OperationContract]
        public string GetLogSheet(string Inicio, string Final, int Pagina, string U, string N, string D, string I, string LangCode)
        {
            try
            {
                Identidad iden = new Identidad(int.Parse(Enigma.Desencriptar(U)), Enigma.Desencriptar(N), int.Parse(Enigma.Desencriptar(D)), Enigma.Desencriptar(I));

                if ((Seguridad.CargarConfiguracionManagement() == 1) && (Seguridad.VerificarSesion(U, N, 1, D, I)))
                {
                    CultureInfo ciLocal = new CultureInfo(LangCode);
                    DateTime S = DateTime.Today;
                    try
                    {
                        //S = DateParser.GetDate(Inicio);
                        S = DateTime.Parse(Inicio, ciLocal);
                    }
                    catch (Exception) { }
                    DateTime F = DateTime.Today;
                    try
                    {
                        //F = DateParser.GetDate(Final);
                        F = DateTime.Parse(Final, ciLocal);
                    }
                    catch (Exception) { }
                    return Tablas.LogSheet(S, F, Pagina, iden)
                        .Replace("Página", L.LBL("LblGENPage"))
                        .Replace("LblGENDate", L.LBL("LblGENDate"))
                        .Replace("LblGENObservations", L.LBL("LblGENObservations"))
                        .Replace("LblGENPermit", L.LBL("LblGENPermit"));
                }
                else
                {
                    CultureInfo ciLocal = new CultureInfo(LangCode);
                    throw new Exception(L.ERR("LblGENWrongUserSession"));
                }
            }
            catch (Exception ex)
            {
                #region Manejo de Errores (Administrador)

                var metodo = MethodBase.GetCurrentMethod().Name;
                var msgError = string.Format(MssgTrace.Trace_Message_Error, metodo, ex);
                LogGenie.ErrorLogSave(ex.Message, 16, msgError, System.Diagnostics.TraceEventType.Error);

                #endregion

                #region Manejo de Errores (Base de Datos)

                try
                {
                    var xException = new Excepcion
                    {
                        EventID = 0,
                        Priority = 16,
                        Severity = TraceEventType.Error,
                        Title = ex.Message,
                        Timestamp = DateTime.Now,
                        MachineName = Environment.MachineName,
                        AppDomainName = Environment.UserDomainName,
                        ProcessID = string.Empty,
                        ProcessName = Environment.CommandLine,
                        ThreadName = string.Empty,
                        Message = ex.ToString()
                    };

                    Logica logica = new Logica();
                    logica.DataBaseLogError(xException);
                }
                catch
                {
                }

                #endregion

                CultureInfo ciLocal = new CultureInfo(LangCode);
                return "<p class=\"SevenMsgError\">" + L.LBL("LblGENWrongQuery") + "</br> " + Memoria.Error + "\n" + ex.Message + Inicio + "F" + Final + Pagina + "</p>";
            }
        }

        #endregion

        #region Sistema

        [WebGet]
        [OperationContract]
        public string GetAccordionForm(string U, string N, string D, string I, string LangCode, int SubDir)
        {
            try
            {
                Identidad iden = new Identidad(int.Parse(Enigma.Desencriptar(U)), Enigma.Desencriptar(N), int.Parse(Enigma.Desencriptar(D)), Enigma.Desencriptar(I));

                if ((Seguridad.CargarConfiguracionManagement() == 1) && (Seguridad.VerificarSesion(U, N, 1, D, I)))
                {
                    CultureInfo ciLocal = new CultureInfo(LangCode);

                    string Dir = "src=\"";

                    if (SubDir == 1)
                    {
                        Dir = "src=\"../";
                    }

                    return ("<div id=\"SevenMenu\">\n" +
                                Logica.GetAccordion(1, iden.U, LangCode, iden).Replace("$HAYOPCIONES$", "") +
                            "</div>\n" +
                            "<table width=\"100%\">\n" +
                                "<tr>\n" +
                                    "<td width=\"50%\">\n" +
                                        "<button type=\"submit\" style=\"width: 100%;\">" +
                                            "<table>" +
                                                "<tr>" +
                                                    "<td><img src=\"img/disk.png\" /></td>" +
                                                    "<td><span style=\"font-size: 8pt;\">LblGENSave</span></td>" +
                                                "</tr>" +
                                            "</table>" +
                                        "</button>" +
                                    "</td>\n" +
                                    "<td width=\"50%\">\n" +
                                        "<button type=\"button\" onclick=\"mostrarAjaxAccordion();\" style=\"width: 100%;\">" +
                                            "<table>" +
                                                "<tr>" +
                                                    "<td><img src=\"img/arrow-return-180-left.png\" /></td>" +
                                                    "<td><span style=\"font-size: 8pt;\">LblGENCancel</span></td>" +
                                                "</tr>" +
                                            "</table>" +
                                        "</button>" +
                                    "</td>\n" +
                                "</tr>\n" +
                            "</table>\n")
                            .Replace("LblGENSave", L.LBL("LblGENSave"))
                            .Replace("LblGENCancel", L.LBL("LblGENCancel"))
                            .Replace("src=\"", Dir);
                }
                else
                {
                    CultureInfo ciLocal = new CultureInfo(LangCode);
                    throw new Exception(L.ERR("LblGENWrongUserSession"));
                }
            }
            catch (Exception ex)
            {
                #region Manejo de Errores (Administrador)

                var metodo = MethodBase.GetCurrentMethod().Name;
                var msgError = string.Format(MssgTrace.Trace_Message_Error, metodo, ex);
                LogGenie.ErrorLogSave(ex.Message, 16, msgError, System.Diagnostics.TraceEventType.Error);

                #endregion

                #region Manejo de Errores (Base de Datos)

                try
                {
                    var xException = new Excepcion
                    {
                        EventID = 0,
                        Priority = 16,
                        Severity = TraceEventType.Error,
                        Title = ex.Message,
                        Timestamp = DateTime.Now,
                        MachineName = Environment.MachineName,
                        AppDomainName = Environment.UserDomainName,
                        ProcessID = string.Empty,
                        ProcessName = Environment.CommandLine,
                        ThreadName = string.Empty,
                        Message = ex.ToString()
                    };

                    Logica logica = new Logica();
                    logica.DataBaseLogError(xException);
                }
                catch
                {
                }

                #endregion

                CultureInfo ciLocal = new CultureInfo(LangCode);
                return "<p class=\"SevenMsgError\"><b>" + L.LBL("LblGENWrongQuery") + ":</b></br> " + L.ERR(ex.Message).Replace("[", "").Replace("]", "") + "</p>";
            }
        }

        [WebGet]
        [OperationContract]
        public string GetAccordion(string U, string N, string D, string I, string LangCode, int SubDir)
        {
            try
            {
                Identidad iden = new Identidad(int.Parse(Enigma.Desencriptar(U)), Enigma.Desencriptar(N), int.Parse(Enigma.Desencriptar(D)), Enigma.Desencriptar(I));

                if ((Seguridad.CargarConfiguracionManagement() == 1) && (Seguridad.VerificarSesion(U, N, 1, D, I)))
                {
                    CultureInfo ciLocal = new CultureInfo(LangCode);

                    string Dir = "src=\"";

                    if (SubDir == 1)
                    {
                        Dir = "src=\"../";
                    }

                    return ("<div id=\"SevenMenu\">\n" +
                                Logica.GetAccordion(0, 0, LangCode, iden).Replace("$HAYOPCIONES$", "") +
                            "</div>\n" +
                            "<button type=\"button\" onclick=\"mostrarAjaxAccordionUser();\" style=\"width: 100%;\">" +
                                "<table>" +
                                    "<tr>" +
                                        "<td><img src=\"img/user.png\" /></td>" +
                                        "<td><span style=\"font-size: 8pt;\">LblGENCustomizeMyMenu</span></td>" +
                                    "</tr>" +
                                "</table>" +
                            "</button>")
                            .Replace("LblGENCustomizeMyMenu", L.LBL("LblGENCustomizeMyMenu"))
                            .Replace("src=\"", Dir);
                }
                else
                {
                    CultureInfo ciLocal = new CultureInfo(LangCode);
                    throw new Exception(L.ERR("LblGENWrongUserSession"));
                }
            }
            catch (Exception ex)
            {
                #region Manejo de Errores (Administrador)

                var metodo = MethodBase.GetCurrentMethod().Name;
                var msgError = string.Format(MssgTrace.Trace_Message_Error, metodo, ex);
                LogGenie.ErrorLogSave(ex.Message, 16, msgError, System.Diagnostics.TraceEventType.Error);

                #endregion

                #region Manejo de Errores (Base de Datos)

                try
                {
                    var xException = new Excepcion
                    {
                        EventID = 0,
                        Priority = 16,
                        Severity = TraceEventType.Error,
                        Title = ex.Message,
                        Timestamp = DateTime.Now,
                        MachineName = Environment.MachineName,
                        AppDomainName = Environment.UserDomainName,
                        ProcessID = string.Empty,
                        ProcessName = Environment.CommandLine,
                        ThreadName = string.Empty,
                        Message = ex.ToString()
                    };

                    Logica logica = new Logica();
                    logica.DataBaseLogError(xException);
                }
                catch
                {
                }

                #endregion

                CultureInfo ciLocal = new CultureInfo(LangCode);
                return "<p class=\"SevenMsgError\"><b>" + L.LBL("LblGENWrongQuery") + ":</b></br> " + L.ERR(ex.Message).Replace("[", "").Replace("]", "") + "</p>";
            }
        }

        [WebGet]
        [OperationContract]
        public string GetMenu(string U, string N, string D, string I, string LangCode, int SubDir)
        {
            try
            {
                Identidad iden = new Identidad(int.Parse(Enigma.Desencriptar(U)), Enigma.Desencriptar(N), int.Parse(Enigma.Desencriptar(D)), Enigma.Desencriptar(I));

                if ((Seguridad.CargarConfiguracionManagement() == 1) && (Seguridad.VerificarSesion(U, N, 1, D, I)))
                {
                    CultureInfo ciLocal = new CultureInfo(LangCode);

                    //string Dir = "src=\"";

                    //if (SubDir == 1)
                    //{
                    //    Dir = "src=\"../";
                    //}

                    return Globals.jqGridGenie.DataTableToJQGridJSON(Logica.GetMenu(0, 0, LangCode, iden));
                    //$("#MenuP ul").append('<li><a href="#tabs-' + i + '"><img src="img/' + datos.rows[i].cell[1] + '" />' + datos.rows[i].cell[2] + '</a></li>');

                    //return ("<div id=\"SevenMenu\">\n" +
                    //            Logica.GetAccordion(0, 0, LangCode, iden).Replace("$HAYOPCIONES$", "") +
                    //        "</div>\n" +
                    //        "<button type=\"button\" onclick=\"mostrarAjaxAccordionUser();\" style=\"width: 100%;\">" +
                    //            "<table>" +
                    //                "<tr>" +
                    //                    "<td><img src=\"img/user.png\" /></td>" +
                    //                    "<td><span style=\"font-size: 8pt;\">LblGENCustomizeMyMenu</span></td>" +
                    //                "</tr>" +
                    //            "</table>" +
                    //        "</button>")
                    //        .Replace("LblGENCustomizeMyMenu", L.LBL("LblGENCustomizeMyMenu"))
                    //        .Replace("src=\"", Dir);
                }
                else
                {
                    CultureInfo ciLocal = new CultureInfo(LangCode);
                    throw new Exception(L.ERR("LblGENWrongUserSession"));
                }
            }
            catch (Exception ex)
            {
                #region Manejo de Errores (Administrador)

                var metodo = MethodBase.GetCurrentMethod().Name;
                var msgError = string.Format(MssgTrace.Trace_Message_Error, metodo, ex);
                LogGenie.ErrorLogSave(ex.Message, 16, msgError, System.Diagnostics.TraceEventType.Error);

                #endregion

                #region Manejo de Errores (Base de Datos)

                try
                {
                    var xException = new Excepcion
                    {
                        EventID = 0,
                        Priority = 16,
                        Severity = TraceEventType.Error,
                        Title = ex.Message,
                        Timestamp = DateTime.Now,
                        MachineName = Environment.MachineName,
                        AppDomainName = Environment.UserDomainName,
                        ProcessID = string.Empty,
                        ProcessName = Environment.CommandLine,
                        ThreadName = string.Empty,
                        Message = ex.ToString()
                    };

                    Logica logica = new Logica();
                    logica.DataBaseLogError(xException);
                }
                catch
                {
                }

                #endregion

                CultureInfo ciLocal = new CultureInfo(LangCode);
                return "<p class=\"SevenMsgError\"><b>" + L.LBL("LblGENWrongQuery") + ":</b></br> " + L.ERR(ex.Message).Replace("[", "").Replace("]", "") + "</p>";
            }
        }

        [WebGet]
        [OperationContract]
        public string GetMenuP(string U, string N, string D, string I, string LangCode, int SubDir)
        {
            try
            {
                Identidad iden = new Identidad(int.Parse(Enigma.Desencriptar(U)), Enigma.Desencriptar(N), int.Parse(Enigma.Desencriptar(D)), Enigma.Desencriptar(I));

                if ((Seguridad.CargarConfiguracionManagement() == 1) && (Seguridad.VerificarSesion(U, N, 1, D, I)))
                {
                    CultureInfo ciLocal = new CultureInfo(LangCode);

                    //string Dir = "src=\"";

                    //if (SubDir == 1)
                    //{
                    //    Dir = "src=\"../";
                    //}

                    return Globals.jqGridGenie.DataTableToJQGridJSON(Logica.GetMenu(1, iden.U, LangCode, iden));
                    //$("#MenuP ul").append('<li><a href="#tabs-' + i + '"><img src="img/' + datos.rows[i].cell[1] + '" />' + datos.rows[i].cell[2] + '</a></li>');

                    //return ("<div id=\"SevenMenu\">\n" +
                    //            Logica.GetAccordion(0, 0, LangCode, iden).Replace("$HAYOPCIONES$", "") +
                    //        "</div>\n" +
                    //        "<button type=\"button\" onclick=\"mostrarAjaxAccordionUser();\" style=\"width: 100%;\">" +
                    //            "<table>" +
                    //                "<tr>" +
                    //                    "<td><img src=\"img/user.png\" /></td>" +
                    //                    "<td><span style=\"font-size: 8pt;\">LblGENCustomizeMyMenu</span></td>" +
                    //                "</tr>" +
                    //            "</table>" +
                    //        "</button>")
                    //        .Replace("LblGENCustomizeMyMenu", L.LBL("LblGENCustomizeMyMenu"))
                    //        .Replace("src=\"", Dir);
                }
                else
                {
                    CultureInfo ciLocal = new CultureInfo(LangCode);
                    throw new Exception(L.ERR("LblGENWrongUserSession"));
                }
            }
            catch (Exception ex)
            {
                #region Manejo de Errores (Administrador)

                var metodo = MethodBase.GetCurrentMethod().Name;
                var msgError = string.Format(MssgTrace.Trace_Message_Error, metodo, ex);
                LogGenie.ErrorLogSave(ex.Message, 16, msgError, System.Diagnostics.TraceEventType.Error);

                #endregion

                #region Manejo de Errores (Base de Datos)

                try
                {
                    var xException = new Excepcion
                    {
                        EventID = 0,
                        Priority = 16,
                        Severity = TraceEventType.Error,
                        Title = ex.Message,
                        Timestamp = DateTime.Now,
                        MachineName = Environment.MachineName,
                        AppDomainName = Environment.UserDomainName,
                        ProcessID = string.Empty,
                        ProcessName = Environment.CommandLine,
                        ThreadName = string.Empty,
                        Message = ex.ToString()
                    };

                    Logica logica = new Logica();
                    logica.DataBaseLogError(xException);
                }
                catch
                {
                }

                #endregion

                CultureInfo ciLocal = new CultureInfo(LangCode);
                return "<p class=\"SevenMsgError\"><b>" + L.LBL("LblGENWrongQuery") + ":</b></br> " + L.ERR(ex.Message).Replace("[", "").Replace("]", "") + "</p>";
            }
        }

        #endregion

        #region Configuración del Usuario

        [WebGet]
        [OperationContract]
        public string PutConfiguracionUsuario(string IdOperador, string impresora, string impresora_cheq, string impresora_fact, string impresora_rec
            , string Eliminado, string U, string N, string D, string I, string LangCode)
        {
            try
            {
                Identidad iden = new Identidad(int.Parse(Enigma.Desencriptar(U)), Enigma.Desencriptar(N), int.Parse(Enigma.Desencriptar(D)), Enigma.Desencriptar(I));

                if ((Seguridad.CargarConfiguracionManagement() == 1) && (Seguridad.VerificarSesion(U, N, 1, D, I)))
                {
                    ConfigUsuario elemento = new ConfigUsuario();
                    elemento.IdOperador = iden.U;
                    elemento.impresora = impresora;
                    elemento.impresora_cheq = impresora_cheq;
                    elemento.impresora_fact = impresora_fact;
                    elemento.impresora_rec = impresora_rec;

                    int res = -1;

                    res = Logica.PutConfiguracionUsuario(elemento, iden);

                    return res != -2147483647 ? res.ToString() : L.ERR("LblGENUserNotAuthorized");
                }
                else
                {
                    throw new Exception(L.LBL("LblGENWrongUserSession"));
                }
            }
            catch (Exception ex)
            {
                #region Manejo de Errores (Administrador)

                var metodo = MethodBase.GetCurrentMethod().Name;
                var msgError = string.Format(MssgTrace.Trace_Message_Error, metodo, ex);
                LogGenie.ErrorLogSave(ex.Message, 16, msgError, System.Diagnostics.TraceEventType.Error);

                #endregion

                #region Manejo de Errores (Base de Datos)

                try
                {
                    var xException = new Excepcion
                    {
                        EventID = 0,
                        Priority = 16,
                        Severity = TraceEventType.Error,
                        Title = ex.Message,
                        Timestamp = DateTime.Now,
                        MachineName = Environment.MachineName,
                        AppDomainName = Environment.UserDomainName,
                        ProcessID = string.Empty,
                        ProcessName = Environment.CommandLine,
                        ThreadName = string.Empty,
                        Message = ex.ToString()
                    };

                    Logica logica = new Logica();
                    logica.DataBaseLogError(xException);
                }
                catch
                {
                }

                #endregion

                return "<p class=\"SevenMsgError\"><b>" + L.LBL("LblGENWrongQuery") + ":</b></br> " + L.ERR(ex.Message).Replace("[", "").Replace("]", "") + "</p>";
            }
        }


        #endregion#region Configuración del Usuario

        #region Bitácora de Seguridad

        //[WebGet]
        //[OperationContract]
        //public string GetModulosCombo(string id, string I, string LangCode)
        //{
        //    try
        //    {
        //        if (Seguridad.CargarConfiguracionManagement() == 1)
        //        {
        //            return HTMLSelects.Modulos();
        //        }
        //        else
        //        {
        //            CultureInfo ciLocal = new CultureInfo(LangCode);
        //            throw new Exception(L.ERR("LblGENWrongUserSession"));
        //        }
        //    }
        //    catch (Exception ex)
        //    {
        //        #region Manejo de Errores (Administrador)

        //        var metodo = MethodBase.GetCurrentMethod().Name;
        //        var msgError = string.Format(MssgTrace.Trace_Message_Error, metodo, ex);
        //        LogGenie.ErrorLogSave(ex.Message, 16, msgError, System.Diagnostics.TraceEventType.Error);

        //        #endregion

        //        #region Manejo de Errores (Base de Datos)

        //        try
        //        {
        //            var xException = new Excepcion
        //            {
        //                EventID = 0,
        //                Priority = 16,
        //                Severity = TraceEventType.Error,
        //                Title = ex.Message,
        //                Timestamp = DateTime.Now,
        //                MachineName = Environment.MachineName,
        //                AppDomainName = Environment.UserDomainName,
        //                ProcessID = string.Empty,
        //                ProcessName = Environment.CommandLine,
        //                ThreadName = string.Empty,
        //                Message = ex.ToString()
        //            };

        //            Logica logica = new Logica();
        //            logica.DataBaseLogError(xException);
        //        }
        //        catch
        //        {
        //        }

        //        #endregion

        //        CultureInfo ciLocal = new CultureInfo(LangCode);
        //        return "<p class=\"SevenMsgError\"><b>" + L.ERR("LblGENWrongQuery") + ":</b></br> " + Memoria.Error + "\n" + ex.Message + "</p>";
        //    }
        //}

        [WebGet]
        [OperationContract]
        public string GetAplicacionesCombo(string id_modulo, string I, string LangCode)
        {
            try
            {
                if (Seguridad.CargarConfiguracionManagement() == 1)
                {
                    return HTMLSelects.Aplicaciones(int.Parse(id_modulo));
                }
                else
                {
                    CultureInfo ciLocal = new CultureInfo(LangCode);
                    throw new Exception(L.ERR("LblGENWrongUserSession"));
                }
            }
            catch (Exception ex)
            {
                #region Manejo de Errores (Administrador)

                var metodo = MethodBase.GetCurrentMethod().Name;
                var msgError = string.Format(MssgTrace.Trace_Message_Error, metodo, ex);
                LogGenie.ErrorLogSave(ex.Message, 16, msgError, System.Diagnostics.TraceEventType.Error);

                #endregion

                #region Manejo de Errores (Base de Datos)

                try
                {
                    var xException = new Excepcion
                    {
                        EventID = 0,
                        Priority = 16,
                        Severity = TraceEventType.Error,
                        Title = ex.Message,
                        Timestamp = DateTime.Now,
                        MachineName = Environment.MachineName,
                        AppDomainName = Environment.UserDomainName,
                        ProcessID = string.Empty,
                        ProcessName = Environment.CommandLine,
                        ThreadName = string.Empty,
                        Message = ex.ToString()
                    };

                    Logica logica = new Logica();
                    logica.DataBaseLogError(xException);
                }
                catch
                {
                }

                #endregion

                CultureInfo ciLocal = new CultureInfo(LangCode);
                return "<p class=\"SevenMsgError\"><b>" + L.ERR("LblGENWrongQuery") + ":</b></br> " + Memoria.Error + "\n" + ex.Message + "</p>";
            }
        }
        
        [WebGet]
        [OperationContract]
        public string GetDatosComboBS(string id_modulo, string I, string LangCode)
        {
            try
            {
                if (Seguridad.CargarConfiguracionManagement() == 1)
                {
                    return HTMLSelects.DatosLog(int.Parse(id_modulo));
                }
                else
                {
                    CultureInfo ciLocal = new CultureInfo(LangCode);
                    throw new Exception(L.ERR("LblGENWrongUserSession"));
                }
            }
            catch (Exception ex)
            {
                #region Manejo de Errores (Administrador)

                var metodo = MethodBase.GetCurrentMethod().Name;
                var msgError = string.Format(MssgTrace.Trace_Message_Error, metodo, ex);
                LogGenie.ErrorLogSave(ex.Message, 16, msgError, System.Diagnostics.TraceEventType.Error);

                #endregion

                #region Manejo de Errores (Base de Datos)

                try
                {
                    var xException = new Excepcion
                    {
                        EventID = 0,
                        Priority = 16,
                        Severity = TraceEventType.Error,
                        Title = ex.Message,
                        Timestamp = DateTime.Now,
                        MachineName = Environment.MachineName,
                        AppDomainName = Environment.UserDomainName,
                        ProcessID = string.Empty,
                        ProcessName = Environment.CommandLine,
                        ThreadName = string.Empty,
                        Message = ex.ToString()
                    };

                    Logica logica = new Logica();
                    logica.DataBaseLogError(xException);
                }
                catch
                {
                }

                #endregion

                CultureInfo ciLocal = new CultureInfo(LangCode);
                return "<p class=\"SevenMsgError\"><b>" + L.ERR("LblGENWrongQuery") + ":</b></br> " + Memoria.Error + "\n" + ex.Message + "</p>";
            }
        }

        [WebGet]
        [OperationContract]
        public string GetOpcionesCombo(string id_app, string I, string LangCode)
        {
            try
            {
                if (Seguridad.CargarConfiguracionManagement() == 1)
                {
                    return HTMLSelects.Opciones(int.Parse(id_app));
                }
                else
                {
                    CultureInfo ciLocal = new CultureInfo(LangCode);
                    throw new Exception(L.ERR("LblGENWrongUserSession"));
                }
            }
            catch (Exception ex)
            {
                #region Manejo de Errores (Administrador)

                var metodo = MethodBase.GetCurrentMethod().Name;
                var msgError = string.Format(MssgTrace.Trace_Message_Error, metodo, ex);
                LogGenie.ErrorLogSave(ex.Message, 16, msgError, System.Diagnostics.TraceEventType.Error);

                #endregion

                #region Manejo de Errores (Base de Datos)

                try
                {
                    var xException = new Excepcion
                    {
                        EventID = 0,
                        Priority = 16,
                        Severity = TraceEventType.Error,
                        Title = ex.Message,
                        Timestamp = DateTime.Now,
                        MachineName = Environment.MachineName,
                        AppDomainName = Environment.UserDomainName,
                        ProcessID = string.Empty,
                        ProcessName = Environment.CommandLine,
                        ThreadName = string.Empty,
                        Message = ex.ToString()
                    };

                    Logica logica = new Logica();
                    logica.DataBaseLogError(xException);
                }
                catch
                {
                }

                #endregion

                CultureInfo ciLocal = new CultureInfo(LangCode);
                return "<p class=\"SevenMsgError\"><b>" + L.ERR("LblGENWrongQuery") + ":</b></br> " + Memoria.Error + "\n" + ex.Message + "</p>";
            }
        }

        #endregion

        #region Terminales

        [WebGet]
        [OperationContract]
        public string GetTerminales(string Eliminado, string Dominio, string U, string N, string D, string I, string LangCode)
        {
            try
            {
                Identidad iden = new Identidad(int.Parse(Enigma.Desencriptar(U)), Enigma.Desencriptar(N), int.Parse(Enigma.Desencriptar(D)), Enigma.Desencriptar(I));

                if ((Seguridad.CargarConfiguracionManagement() == 1) && (Seguridad.VerificarSesion(U, N, 1, D, I)))
                {
                    bool Eliminados = false;
                    try
                    {
                        Eliminados = int.Parse(Eliminado) == 0 ? false : true;
                    }
                    catch { }

                    Terminal elemento = new Terminal();
                    elemento.id_terminal = 0;

                    return Globals.jqGridGenie.DataTableToJQGridJSON(Logica.GetTerminales(elemento, Eliminados, iden));
                }
                else
                {
                    throw new Exception(L.LBL("LblGENWrongUserSession"));
                }
            }
            catch (Exception ex)
            {
                #region Manejo de Errores (Administrador)

                var metodo = MethodBase.GetCurrentMethod().Name;
                var msgError = string.Format(MssgTrace.Trace_Message_Error, metodo, ex);
                LogGenie.ErrorLogSave(ex.Message, 16, msgError, System.Diagnostics.TraceEventType.Error);

                #endregion

                #region Manejo de Errores (Base de Datos)

                try
                {
                    var xException = new Excepcion
                    {
                        EventID = 0,
                        Priority = 16,
                        Severity = TraceEventType.Error,
                        Title = ex.Message,
                        Timestamp = DateTime.Now,
                        MachineName = Environment.MachineName,
                        AppDomainName = Environment.UserDomainName,
                        ProcessID = string.Empty,
                        ProcessName = Environment.CommandLine,
                        ThreadName = string.Empty,
                        Message = ex.ToString()
                    };

                    Logica logica = new Logica();
                    logica.DataBaseLogError(xException);
                }
                catch
                {
                }

                #endregion

                return "<p class=\"SevenMsgError\"><b>" + L.LBL("LblGENWrongQuery") + ":</b></br> " + L.ERR(ex.Message).Replace("[", "").Replace("]", "") + "</p>";
            }
        }

        [WebGet]
        [OperationContract]
        public string PutTerminales(string id_terminal, string nombre, string activa, string Eliminado, string U, string N, string D, string I, string LangCode)
        {
            try
            {
                Identidad iden = new Identidad(int.Parse(Enigma.Desencriptar(U)), Enigma.Desencriptar(N), int.Parse(Enigma.Desencriptar(D)), Enigma.Desencriptar(I));

                if ((Seguridad.CargarConfiguracionManagement() == 1) && (Seguridad.VerificarSesion(U, N, 1, D, I)))
                {
                    Terminal elemento = new Terminal();
                    try
                    {
                        elemento.id_terminal = int.Parse(id_terminal);
                    }
                    catch
                    {
                        elemento.id_terminal = 0;
                    }
                    elemento.nombre = nombre;

                    elemento.activa = int.Parse(Eliminado) == 1 ? true : false;

                    int res = -1;

                    res = Logica.PutTerminales(elemento, iden);

                    return res != -2147483647 ? res.ToString() : L.ERR("LblGENUserNotAuthorized");
                }
                else
                {
                    throw new Exception(L.LBL("LblGENWrongUserSession"));
                }
            }
            catch (Exception ex)
            {
                #region Manejo de Errores (Administrador)

                var metodo = MethodBase.GetCurrentMethod().Name;
                var msgError = string.Format(MssgTrace.Trace_Message_Error, metodo, ex);
                LogGenie.ErrorLogSave(ex.Message, 16, msgError, System.Diagnostics.TraceEventType.Error);

                #endregion

                #region Manejo de Errores (Base de Datos)

                try
                {
                    var xException = new Excepcion
                    {
                        EventID = 0,
                        Priority = 16,
                        Severity = TraceEventType.Error,
                        Title = ex.Message,
                        Timestamp = DateTime.Now,
                        MachineName = Environment.MachineName,
                        AppDomainName = Environment.UserDomainName,
                        ProcessID = string.Empty,
                        ProcessName = Environment.CommandLine,
                        ThreadName = string.Empty,
                        Message = ex.ToString()
                    };

                    Logica logica = new Logica();
                    logica.DataBaseLogError(xException);
                }
                catch
                {
                }

                #endregion

                return "<p class=\"SevenMsgError\"><b>" + L.LBL("LblGENWrongQuery") + ":</b></br> " + L.ERR(ex.Message).Replace("[", "").Replace("]", "") + "</p>";
            }
        }

        #endregion

        #region Entidades

        [WebGet]
        [OperationContract]
        public string GetEntidades(string Eliminado, string Dominio, string U, string N, string D, string I, string LangCode)
        {
            try
            {
                Identidad iden = new Identidad(int.Parse(Enigma.Desencriptar(U)), Enigma.Desencriptar(N), int.Parse(Enigma.Desencriptar(D)), Enigma.Desencriptar(I));

                if ((Seguridad.CargarConfiguracionManagement() == 1) && (Seguridad.VerificarSesion(U, N, 1, D, I)))
                {
                    bool Eliminados = false;
                    try
                    {
                        Eliminados = int.Parse(Eliminado) == 0 ? false : true;
                    }
                    catch { }

                    Entidad elemento = new Entidad();
                    elemento.id_juego = 0;

                    return Globals.jqGridGenie.DataTableToJQGridJSON(Logica.GetEntidades(elemento, Eliminados, iden));
                }
                else
                {
                    throw new Exception(L.LBL("LblGENWrongUserSession"));
                }
            }
            catch (Exception ex)
            {
                #region Manejo de Errores (Administrador)

                var metodo = MethodBase.GetCurrentMethod().Name;
                var msgError = string.Format(MssgTrace.Trace_Message_Error, metodo, ex);
                LogGenie.ErrorLogSave(ex.Message, 16, msgError, System.Diagnostics.TraceEventType.Error);

                #endregion

                #region Manejo de Errores (Base de Datos)

                try
                {
                    var xException = new Excepcion
                    {
                        EventID = 0,
                        Priority = 16,
                        Severity = TraceEventType.Error,
                        Title = ex.Message,
                        Timestamp = DateTime.Now,
                        MachineName = Environment.MachineName,
                        AppDomainName = Environment.UserDomainName,
                        ProcessID = string.Empty,
                        ProcessName = Environment.CommandLine,
                        ThreadName = string.Empty,
                        Message = ex.ToString()
                    };

                    Logica logica = new Logica();
                    logica.DataBaseLogError(xException);
                }
                catch
                {
                }

                #endregion

                return "<p class=\"SevenMsgError\"><b>" + L.LBL("LblGENWrongQuery") + ":</b></br> " + L.ERR(ex.Message).Replace("[", "").Replace("]", "") + "</p>";
            }
        }

        [WebGet]
        [OperationContract]
        public string Get_BasesFrontCombo(string Dominio, string U, string N, string D, string I, string LangCode)
        {
            try
            {
                Identidad iden = new Identidad(int.Parse(Enigma.Desencriptar(U)), Enigma.Desencriptar(N), int.Parse(Enigma.Desencriptar(D)), Enigma.Desencriptar(I));

                if ((Seguridad.CargarConfiguracionManagement() == 1) && (Seguridad.VerificarSesion(U, N, 1, D, I)))
                {
                    return Globals.jqGridGenie.DataTableToJQGridCombo(HTMLSelects.Get_BasesFrontCombo_JQ());
                }
                else
                {
                    throw new Exception(L.LBL("LblGENWrongUserSession"));
                }
            }
            catch (Exception ex)
            {
                #region Manejo de Errores (Administrador)

                var metodo = MethodBase.GetCurrentMethod().Name;
                var msgError = string.Format(MssgTrace.Trace_Message_Error, metodo, ex);
                LogGenie.ErrorLogSave(ex.Message, 16, msgError, System.Diagnostics.TraceEventType.Error);

                #endregion

                #region Manejo de Errores (Base de Datos)

                try
                {
                    var xException = new Excepcion
                    {
                        EventID = 0,
                        Priority = 16,
                        Severity = TraceEventType.Error,
                        Title = ex.Message,
                        Timestamp = DateTime.Now,
                        MachineName = Environment.MachineName,
                        AppDomainName = Environment.UserDomainName,
                        ProcessID = string.Empty,
                        ProcessName = Environment.CommandLine,
                        ThreadName = string.Empty,
                        Message = ex.ToString()
                    };

                    Logica logica = new Logica();
                    logica.DataBaseLogError(xException);
                }
                catch
                {
                }

                #endregion

                return "<p class=\"SevenMsgError\"><b>" + L.LBL("LblGENWrongQuery") + ":</b></br> " + L.ERR(ex.Message).Replace("[", "").Replace("]", "") + "</p>";
            }
        }

        [WebGet]
        [OperationContract]
        public string PutEntidades(string id_juego, string descripcion, string activo, string log_sheet, string front_principal, string Eliminado, string U, string N, string D, string I, string LangCode)
        {
            try
            {
                Identidad iden = new Identidad(int.Parse(Enigma.Desencriptar(U)), Enigma.Desencriptar(N), int.Parse(Enigma.Desencriptar(D)), Enigma.Desencriptar(I));

                if ((Seguridad.CargarConfiguracionManagement() == 1) && (Seguridad.VerificarSesion(U, N, 1, D, I)))
                {
                    Entidad elemento = new Entidad();
                    try
                    {
                        elemento.id_juego = int.Parse(id_juego);
                    }
                    catch
                    {
                        elemento.id_juego = 0;
                    }
                    elemento.descripcion = descripcion;

                    try
                    {
                        elemento.log_sheet = int.Parse(log_sheet) == 1 ? true : false;
                    }
                    catch
                    {
                        elemento.log_sheet = false;
                    }

                    try
                    {
                        elemento.front_principal = int.Parse(front_principal);
                    }
                    catch
                    {
                        elemento.front_principal = 0;
                    }

                    elemento.activo = int.Parse(Eliminado) == 1 ? true : false;

                    int res = -1;

                    res = Logica.PutEntidades(elemento, iden);

                    return res != -2147483647 ? res.ToString() : L.ERR("LblGENUserNotAuthorized");
                }
                else
                {
                    throw new Exception(L.LBL("LblGENWrongUserSession"));
                }
            }
            catch (Exception ex)
            {
                #region Manejo de Errores (Administrador)

                var metodo = MethodBase.GetCurrentMethod().Name;
                var msgError = string.Format(MssgTrace.Trace_Message_Error, metodo, ex);
                LogGenie.ErrorLogSave(ex.Message, 16, msgError, System.Diagnostics.TraceEventType.Error);

                #endregion

                #region Manejo de Errores (Base de Datos)

                try
                {
                    var xException = new Excepcion
                    {
                        EventID = 0,
                        Priority = 16,
                        Severity = TraceEventType.Error,
                        Title = ex.Message,
                        Timestamp = DateTime.Now,
                        MachineName = Environment.MachineName,
                        AppDomainName = Environment.UserDomainName,
                        ProcessID = string.Empty,
                        ProcessName = Environment.CommandLine,
                        ThreadName = string.Empty,
                        Message = ex.ToString()
                    };

                    Logica logica = new Logica();
                    logica.DataBaseLogError(xException);
                }
                catch
                {
                }

                #endregion

                return "<p class=\"SevenMsgError\"><b>" + L.LBL("LblGENWrongQuery") + ":</b></br> " + L.ERR(ex.Message).Replace("[", "").Replace("]", "") + "</p>";
            }
        }

        #endregion

        #region Datos

        [WebGet]
        [OperationContract]
        public string GetDatos(string id_juego, string Dominio, string U, string N, string D, string I, string LangCode)
        {
            try
            {
                Identidad iden = new Identidad(int.Parse(Enigma.Desencriptar(U)), Enigma.Desencriptar(N), int.Parse(Enigma.Desencriptar(D)), Enigma.Desencriptar(I));

                if ((Seguridad.CargarConfiguracionManagement() == 1) && (Seguridad.VerificarSesion(U, N, 1, D, I)))
                {
                    Dato elemento = new Dato();
                    elemento.id_juego = int.Parse(id_juego);

                    return Globals.jqGridGenie.DataTableToJQGridJSON(Logica.GetDatos(elemento, iden));
                }
                else
                {
                    throw new Exception(L.LBL("LblGENWrongUserSession"));
                }
            }
            catch (Exception ex)
            {
                #region Manejo de Errores (Administrador)

                var metodo = MethodBase.GetCurrentMethod().Name;
                var msgError = string.Format(MssgTrace.Trace_Message_Error, metodo, ex);
                LogGenie.ErrorLogSave(ex.Message, 16, msgError, System.Diagnostics.TraceEventType.Error);

                #endregion

                #region Manejo de Errores (Base de Datos)

                try
                {
                    var xException = new Excepcion
                    {
                        EventID = 0,
                        Priority = 16,
                        Severity = TraceEventType.Error,
                        Title = ex.Message,
                        Timestamp = DateTime.Now,
                        MachineName = Environment.MachineName,
                        AppDomainName = Environment.UserDomainName,
                        ProcessID = string.Empty,
                        ProcessName = Environment.CommandLine,
                        ThreadName = string.Empty,
                        Message = ex.ToString()
                    };

                    Logica logica = new Logica();
                    logica.DataBaseLogError(xException);
                }
                catch
                {
                }

                #endregion

                return "<p class=\"SevenMsgError\"><b>" + L.LBL("LblGENWrongQuery") + ":</b></br> " + L.ERR(ex.Message).Replace("[", "").Replace("]", "") + "</p>";
            }
        }

        [WebGet]
        [OperationContract]
        public string PutDatos(string id_datos, string id_juego, string id_modulo, string base_datos, 
            string descripcion, string origen_datos, string login, string password, string servidor, 
            string backup_antes, string backup_desp, string linked_server, string Eliminado, string U, string N, string D, string I, string LangCode)
        {
            try
            {
                Identidad iden = new Identidad(int.Parse(Enigma.Desencriptar(U)), Enigma.Desencriptar(N), int.Parse(Enigma.Desencriptar(D)), Enigma.Desencriptar(I));

                if ((Seguridad.CargarConfiguracionManagement() == 1) && (Seguridad.VerificarSesion(U, N, 1, D, I)))
                {
                    Dato elemento = new Dato();
                    try
                    {
                        elemento.id_datos = int.Parse(id_datos);
                    }
                    catch
                    {
                        elemento.id_datos = 0;
                    }
                    elemento.id_juego = int.Parse(id_juego);
                    elemento.id_modulo = int.Parse(id_modulo);
                    elemento.base_datos = base_datos;
                    elemento.descripcion = descripcion;
                    elemento.origen_datos = origen_datos;
                    elemento.login = login;
                    elemento.password = password;
                    elemento.servidor = servidor;

                    if (backup_antes == null)
                    {
                        elemento.backup_antes = "";
                    }
                    else
                    {
                        elemento.backup_antes = backup_antes;
                    }

                    if (backup_desp == null)
                    {
                        elemento.backup_desp = "";
                    }
                    else
                    {
                        elemento.backup_desp = backup_desp = "";
                    }

                    elemento.linked_server = linked_server;

                    elemento.eliminado = int.Parse(Eliminado);

                    int res = -1;

                    res = Logica.PutDatos(elemento, iden);

                    return res != -2147483647 ? res.ToString() : L.ERR("LblGENUserNotAuthorized");
                }
                else
                {
                    throw new Exception(L.LBL("LblGENWrongUserSession"));
                }
            }
            //catch (SqlException e)
            //{
            //    var code = e.Number;

                //switch(code)
                //{
                //    case 208:
                //        {
                //            return "<p class=\"SevenMsgError\"><b>" + L.LBL("LblGENWrongQuery") + ":</b></br> " + L.ERR("ERR_GEN_FAL_DAT").Replace("[", "").Replace("]", "") + "</p>";
                //        }
                //    case 4060:
                //        {
                //            return "<p class=\"SevenMsgError\"><b>" + L.LBL("LblGENWrongQuery") + ":</b></br> " + L.ERR("ERR_GEN_BD_EXI").Replace("[", "").Replace("]", "") + "</p>";
                //        }
                //    case 18456:
                //        {
                //            return "<p class=\"SevenMsgError\"><b>" + L.LBL("LblGENWrongQuery") + ":</b></br> " + L.ERR("LblGENWrongUserPass").Replace("[", "").Replace("]", "") + "</p>";
                //        }
                //}

            //    return "<p class=\"SevenMsgError\"><b>" + L.LBL("LblGENWrongQuery") + ":</b></br> " + L.ERR(e.Message).Replace("[", "").Replace("]", "") + "</p>";
            //}
            catch (Exception ex)
            {
                #region Manejo de Errores (Administrador)

                var metodo = MethodBase.GetCurrentMethod().Name;
                var msgError = string.Format(MssgTrace.Trace_Message_Error, metodo, ex);
                LogGenie.ErrorLogSave(ex.Message, 16, msgError, System.Diagnostics.TraceEventType.Error);
                #endregion

                #region Manejo de Errores (Base de Datos)

                try
                {
                    var xException = new Excepcion
                    {
                        EventID = 0,
                        Priority = 16,
                        Severity = TraceEventType.Error,
                        Title = ex.Message,
                        Timestamp = DateTime.Now,
                        MachineName = Environment.MachineName,
                        AppDomainName = Environment.UserDomainName,
                        ProcessID = string.Empty,
                        ProcessName = Environment.CommandLine,
                        ThreadName = string.Empty,
                        Message = ex.ToString()
                    };
                    
                    Logica logica = new Logica();
                    logica.DataBaseLogError(xException);
                }
                catch
                {
                }

                #endregion

                return "<p class=\"SevenMsgError\"><b>" + L.LBL("LblGENWrongQuery") + ":</b></br> " + L.ERR(ex.Message).Replace("[", "").Replace("]", "") + "</p>";
            }
        }

        [WebGet]
        [OperationContract]
        public string GetFechaHotelera(string Servidor, string BaseDatos, string User, string Pass, string Dominio, string U, string N, string D, string I, string LangCode)
        {
            try
            {
                Identidad iden = new Identidad(int.Parse(Enigma.Desencriptar(U)), Enigma.Desencriptar(N), int.Parse(Enigma.Desencriptar(D)), Enigma.Desencriptar(I));

                if ((Seguridad.CargarConfiguracionManagement() == 1) && (Seguridad.VerificarSesion(U, N, 1, D, I)))
                {
                    Dato elemento = new Dato();
                    elemento.servidor = Servidor;
                    elemento.base_datos = BaseDatos;
                    elemento.login = User;
                    elemento.password = Pass;

                    return Globals.jqGridGenie.DataTableToJQGridJSON(Logica.GetFechaHotelera(elemento, iden));
                }
                else
                {
                    throw new Exception(L.LBL("LblGENWrongUserSession"));
                }
            }
            catch (Exception ex)
            {
                #region Manejo de Errores (Administrador)

                var metodo = MethodBase.GetCurrentMethod().Name;
                var msgError = string.Format(MssgTrace.Trace_Message_Error, metodo, ex);
                LogGenie.ErrorLogSave(ex.Message, 16, msgError, System.Diagnostics.TraceEventType.Error);

                #endregion

                #region Manejo de Errores (Base de Datos)

                try
                {
                    var xException = new Excepcion
                    {
                        EventID = 0,
                        Priority = 16,
                        Severity = TraceEventType.Error,
                        Title = ex.Message,
                        Timestamp = DateTime.Now,
                        MachineName = Environment.MachineName,
                        AppDomainName = Environment.UserDomainName,
                        ProcessID = string.Empty,
                        ProcessName = Environment.CommandLine,
                        ThreadName = string.Empty,
                        Message = ex.ToString()
                    };

                    Logica logica = new Logica();
                    logica.DataBaseLogError(xException);
                }
                catch
                {
                }

                #endregion

                return "<p class=\"SevenMsgError\"><b>" + L.LBL("LblGENWrongQuery") + ":</b></br> " + L.ERR(ex.Message).Replace("[", "").Replace("]", "") + "</p>";
            }
        }

        [WebGet]
        [OperationContract]
        public string PutFechaHotelera(string Servidor, string BaseDatos, string User, string Pass,  string FechaHotelera, string U, string N, string D, string I, string LangCode)
        {
            try
            {
                Identidad iden = new Identidad(int.Parse(Enigma.Desencriptar(U)), Enigma.Desencriptar(N), int.Parse(Enigma.Desencriptar(D)), Enigma.Desencriptar(I));

                if ((Seguridad.CargarConfiguracionManagement() == 1) && (Seguridad.VerificarSesion(U, N, 1, D, I)))
                {
                    Dato elemento = new Dato();

                    DateTime Fecha = new DateTime();

                    elemento.servidor = Servidor;
                    elemento.base_datos = BaseDatos;
                    elemento.login = User;
                    elemento.password = Pass;

                    try
                    {
                        Fecha = DateTime.Parse(FechaHotelera);
                    }
                    catch
                    {
                        Fecha = DateTime.Now;
                    }

                    int res = -1;

                    res = Logica.PutFechaHotelera(elemento,Fecha, iden);

                    return res != -2147483647 ? res.ToString() : L.ERR("LblGENUserNotAuthorized");
                }
                else
                {
                    throw new Exception(L.LBL("LblGENWrongUserSession"));
                }
            }
            catch (Exception ex)
            {
                #region Manejo de Errores (Administrador)

                var metodo = MethodBase.GetCurrentMethod().Name;
                var msgError = string.Format(MssgTrace.Trace_Message_Error, metodo, ex);
                LogGenie.ErrorLogSave(ex.Message, 16, msgError, System.Diagnostics.TraceEventType.Error);

                #endregion

                #region Manejo de Errores (Base de Datos)

                try
                {
                    var xException = new Excepcion
                    {
                        EventID = 0,
                        Priority = 16,
                        Severity = TraceEventType.Error,
                        Title = ex.Message,
                        Timestamp = DateTime.Now,
                        MachineName = Environment.MachineName,
                        AppDomainName = Environment.UserDomainName,
                        ProcessID = string.Empty,
                        ProcessName = Environment.CommandLine,
                        ThreadName = string.Empty,
                        Message = ex.ToString()
                    };

                    Logica logica = new Logica();
                    logica.DataBaseLogError(xException);
                }
                catch
                {
                }

                #endregion

                return "<p class=\"SevenMsgError\"><b>" + L.LBL("LblGENWrongQuery") + ":</b></br> " + L.ERR(ex.Message).Replace("[", "").Replace("]", "") + "</p>";
            }
        }

        #endregion

        #region Empresas

        [WebGet]
        [OperationContract]
        public string GetEmpresas(string Eliminado, string Dominio, string U, string N, string D, string I, string LangCode)
        {
            try
            {
                Identidad iden = new Identidad(int.Parse(Enigma.Desencriptar(U)), Enigma.Desencriptar(N), int.Parse(Enigma.Desencriptar(D)), Enigma.Desencriptar(I));

                if ((Seguridad.CargarConfiguracionManagement() == 1) && (Seguridad.VerificarSesion(U, N, 1, D, I)))
                {
                    Empresa elemento = new Empresa();
                    elemento.id_entidad = 0;

                    return Globals.jqGridGenie.DataTableToJQGridJSON(Logica.GetEmpresas(elemento, iden));
                }
                else
                {
                    throw new Exception(L.LBL("LblGENWrongUserSession"));
                }
            }
            catch (Exception ex)
            {
                #region Manejo de Errores (Administrador)

                var metodo = MethodBase.GetCurrentMethod().Name;
                var msgError = string.Format(MssgTrace.Trace_Message_Error, metodo, ex);
                LogGenie.ErrorLogSave(ex.Message, 16, msgError, System.Diagnostics.TraceEventType.Error);

                #endregion

                #region Manejo de Errores (Base de Datos)

                try
                {
                    var xException = new Excepcion
                    {
                        EventID = 0,
                        Priority = 16,
                        Severity = TraceEventType.Error,
                        Title = ex.Message,
                        Timestamp = DateTime.Now,
                        MachineName = Environment.MachineName,
                        AppDomainName = Environment.UserDomainName,
                        ProcessID = string.Empty,
                        ProcessName = Environment.CommandLine,
                        ThreadName = string.Empty,
                        Message = ex.ToString()
                    };

                    Logica logica = new Logica();
                    logica.DataBaseLogError(xException);
                }
                catch
                {
                }

                #endregion

                return "<p class=\"SevenMsgError\"><b>" + L.LBL("LblGENWrongQuery") + ":</b></br> " + L.ERR(ex.Message).Replace("[", "").Replace("]", "") + "</p>";
            }
        }

        [WebGet]
        [OperationContract]
        public string PutEmpresas(string id_entidad, string nombre, string logo, string direccion1, string telefonos, string fax, 
            string e_mail, string fecha_entidad, string juego_activo, string cedula, string U, string N, string D, string I, string LangCode)
        {
            try
            {
                Identidad iden = new Identidad(int.Parse(Enigma.Desencriptar(U)), Enigma.Desencriptar(N), int.Parse(Enigma.Desencriptar(D)), Enigma.Desencriptar(I));

                if ((Seguridad.CargarConfiguracionManagement() == 1) && (Seguridad.VerificarSesion(U, N, 1, D, I)))
                {
                    Empresa elemento = new Empresa();
                    try
                    {
                        elemento.id_entidad = int.Parse(id_entidad);
                    }
                    catch
                    {
                        elemento.id_entidad = 0;
                    }

                    try
                    {
                        elemento.logo = Convert.FromBase64String(logo);
                    }
                    catch
                    {
                        elemento.logo = null;
                    }

                    elemento.nombre = nombre;
                    elemento.direccion1 = direccion1;
                    elemento.telefonos = telefonos;
                    elemento.fax = fax;
                    elemento.e_mail = e_mail;
                    elemento.fecha_entidad = DateTime.Parse(fecha_entidad);
                    //elemento.juego_activo = int.Parse(juego_activo);
                    elemento.cedula = cedula;

                    int res = -1;

                    res = Logica.PutEmpresas(elemento, iden);

                    return res != -2147483647 ? res.ToString() : L.ERR("LblGENUserNotAuthorized");
                }
                else
                {
                    throw new Exception(L.LBL("LblGENWrongUserSession"));
                }
            }
            catch (Exception ex)
            {
                #region Manejo de Errores (Administrador)

                var metodo = MethodBase.GetCurrentMethod().Name;
                var msgError = string.Format(MssgTrace.Trace_Message_Error, metodo, ex);
                LogGenie.ErrorLogSave(ex.Message, 16, msgError, System.Diagnostics.TraceEventType.Error);

                #endregion

                #region Manejo de Errores (Base de Datos)

                try
                {
                    var xException = new Excepcion
                    {
                        EventID = 0,
                        Priority = 16,
                        Severity = TraceEventType.Error,
                        Title = ex.Message,
                        Timestamp = DateTime.Now,
                        MachineName = Environment.MachineName,
                        AppDomainName = Environment.UserDomainName,
                        ProcessID = string.Empty,
                        ProcessName = Environment.CommandLine,
                        ThreadName = string.Empty,
                        Message = ex.ToString()
                    };

                    Logica logica = new Logica();
                    logica.DataBaseLogError(xException);
                }
                catch
                {
                }

                #endregion

                return "<p class=\"SevenMsgError\"><b>" + L.LBL("LblGENWrongQuery") + ":</b></br> " + L.ERR(ex.Message).Replace("[", "").Replace("]", "") + "</p>";
            }
        }


        #endregion

        #region Monedas

        [WebGet]
        [OperationContract]
        public string GetMonedas(string Eliminado, string Dominio, string U, string N, string D, string I, string LangCode)
        {
            try
            {
                Identidad iden = new Identidad(int.Parse(Enigma.Desencriptar(U)), Enigma.Desencriptar(N), int.Parse(Enigma.Desencriptar(D)), Enigma.Desencriptar(I));

                if ((Seguridad.CargarConfiguracionManagement() == 1) && (Seguridad.VerificarSesion(U, N, 1, D, I)))
                {
                    bool Eliminados = false;
                    try
                    {
                        Eliminados = int.Parse(Eliminado) == 0 ? false : true;
                    }
                    catch { }

                    Moneda elemento = new Moneda();
                    elemento.id_mone = 0;

                    return Globals.jqGridGenie.DataTableToJQGridJSON(Logica.GetMonedas(elemento, Eliminados, iden));
                }
                else
                {
                    throw new Exception(L.LBL("LblGENWrongUserSession"));
                }
            }
            catch (Exception ex)
            {
                #region Manejo de Errores (Administrador)

                var metodo = MethodBase.GetCurrentMethod().Name;
                var msgError = string.Format(MssgTrace.Trace_Message_Error, metodo, ex);
                LogGenie.ErrorLogSave(ex.Message, 16, msgError, System.Diagnostics.TraceEventType.Error);

                #endregion

                #region Manejo de Errores (Base de Datos)

                try
                {
                    var xException = new Excepcion
                    {
                        EventID = 0,
                        Priority = 16,
                        Severity = TraceEventType.Error,
                        Title = ex.Message,
                        Timestamp = DateTime.Now,
                        MachineName = Environment.MachineName,
                        AppDomainName = Environment.UserDomainName,
                        ProcessID = string.Empty,
                        ProcessName = Environment.CommandLine,
                        ThreadName = string.Empty,
                        Message = ex.ToString()
                    };

                    Logica logica = new Logica();
                    logica.DataBaseLogError(xException);
                }
                catch
                {
                }

                #endregion

                return "<p class=\"SevenMsgError\"><b>" + L.LBL("LblGENWrongQuery") + ":</b></br> " + L.ERR(ex.Message).Replace("[", "").Replace("]", "") + "</p>";
            }
        }

        [WebGet]
        [OperationContract]
        public string PutMonedas(string id_mone, string cod_mone, string desc_mone, string tasa, string comision, string decimales,
            string convertible, string facturable, string fecha_ult, string refer_mone, string Eliminado, string U, string N, string D, string I, string LangCode)
        {
            try
            {
                Identidad iden = new Identidad(int.Parse(Enigma.Desencriptar(U)), Enigma.Desencriptar(N), int.Parse(Enigma.Desencriptar(D)), Enigma.Desencriptar(I));

                if ((Seguridad.CargarConfiguracionManagement() == 1) && (Seguridad.VerificarSesion(U, N, 1, D, I)))
                {
                    Moneda elemento = new Moneda();

                    try
                    {
                        elemento.id_mone = int.Parse(id_mone);
                    }
                    catch
                    {
                        elemento.id_mone = 0;
                    }

                    try
                    {
                        elemento.convertible = int.Parse(convertible) == 1 ? true : false;
                    }
                    catch
                    {
                        elemento.convertible = false;
                    }

                    try
                    {
                        elemento.facturable = int.Parse(facturable) == 1 ? true : false;
                    }
                    catch
                    {
                        elemento.facturable = false;
                    }

                    try
                    {
                        elemento.refer_mone = int.Parse(refer_mone) == 1 ? true : false;
                    }
                    catch
                    {
                        elemento.refer_mone = false;
                    }

                    elemento.cod_mone = cod_mone;
                    elemento.desc_mone = desc_mone;
                    elemento.tasa = decimal.Parse(tasa);
                    elemento.comision = decimal.Parse(comision);
                    elemento.decimales = int.Parse(decimales);
                    elemento.fecha_ult = DateTime.Now;
                    //elemento.fecha_ult = DateTime.Parse(fecha_ult);

                    elemento.eliminado = int.Parse(Eliminado) == 1 ? true : false;

                    int res = -1;

                    res = Logica.PutMonedas(elemento, iden);

                    return res != -2147483647 ? res.ToString() : L.ERR("LblGENUserNotAuthorized");
                }
                else
                {
                    throw new Exception(L.LBL("LblGENWrongUserSession"));
                }
            }
            catch (Exception ex)
            {
                #region Manejo de Errores (Administrador)

                var metodo = MethodBase.GetCurrentMethod().Name;
                var msgError = string.Format(MssgTrace.Trace_Message_Error, metodo, ex);
                LogGenie.ErrorLogSave(ex.Message, 16, msgError, System.Diagnostics.TraceEventType.Error);

                #endregion

                #region Manejo de Errores (Base de Datos)

                try
                {
                    var xException = new Excepcion
                    {
                        EventID = 0,
                        Priority = 16,
                        Severity = TraceEventType.Error,
                        Title = ex.Message,
                        Timestamp = DateTime.Now,
                        MachineName = Environment.MachineName,
                        AppDomainName = Environment.UserDomainName,
                        ProcessID = string.Empty,
                        ProcessName = Environment.CommandLine,
                        ThreadName = string.Empty,
                        Message = ex.ToString()
                    };

                    Logica logica = new Logica();
                    logica.DataBaseLogError(xException);
                }
                catch
                {
                }

                #endregion

                return "<p class=\"SevenMsgError\"><b>" + L.LBL("LblGENWrongQuery") + ":</b></br> " + L.ERR(ex.Message).Replace("[", "").Replace("]", "") + "</p>";
            }
        }


        #endregion

        #region Nacionalidades

        [WebGet]
        [OperationContract]
        public string GetNacionalidades(string Eliminado, string Dominio, string U, string N, string D, string I, string LangCode)
        {
            try
            {
                Identidad iden = new Identidad(int.Parse(Enigma.Desencriptar(U)), Enigma.Desencriptar(N), int.Parse(Enigma.Desencriptar(D)), Enigma.Desencriptar(I));

                if ((Seguridad.CargarConfiguracionManagement() == 1) && (Seguridad.VerificarSesion(U, N, 1, D, I)))
                {
                    bool Eliminados = false;
                    try
                    {
                        Eliminados = int.Parse(Eliminado) == 0 ? false : true;
                    }
                    catch { }

                    Nacionalidad elemento = new Nacionalidad();
                    elemento.id_naci = 0;

                    return Globals.jqGridGenie.DataTableToJQGridJSON(Logica.GetNacionalidades(elemento, Eliminados, iden));
                }
                else
                {
                    throw new Exception(L.LBL("LblGENWrongUserSession"));
                }
            }
            catch (Exception ex)
            {
                #region Manejo de Errores (Administrador)

                var metodo = MethodBase.GetCurrentMethod().Name;
                var msgError = string.Format(MssgTrace.Trace_Message_Error, metodo, ex);
                LogGenie.ErrorLogSave(ex.Message, 16, msgError, System.Diagnostics.TraceEventType.Error);

                #endregion

                #region Manejo de Errores (Base de Datos)

                try
                {
                    var xException = new Excepcion
                    {
                        EventID = 0,
                        Priority = 16,
                        Severity = TraceEventType.Error,
                        Title = ex.Message,
                        Timestamp = DateTime.Now,
                        MachineName = Environment.MachineName,
                        AppDomainName = Environment.UserDomainName,
                        ProcessID = string.Empty,
                        ProcessName = Environment.CommandLine,
                        ThreadName = string.Empty,
                        Message = ex.ToString()
                    };

                    Logica logica = new Logica();
                    logica.DataBaseLogError(xException);
                }
                catch
                {
                }

                #endregion

                return "<p class=\"SevenMsgError\"><b>" + L.LBL("LblGENWrongQuery") + ":</b></br> " + L.ERR(ex.Message).Replace("[", "").Replace("]", "") + "</p>";
            }
        }

        [WebGet]
        [OperationContract]
        public string PutNacionalidades(string id_naci, string nacionalidad, string desc_nac, string Eliminado, string U, string N, string D, string I, string LangCode)
        {
            try
            {
                Identidad iden = new Identidad(int.Parse(Enigma.Desencriptar(U)), Enigma.Desencriptar(N), int.Parse(Enigma.Desencriptar(D)), Enigma.Desencriptar(I));

                if ((Seguridad.CargarConfiguracionManagement() == 1) && (Seguridad.VerificarSesion(U, N, 1, D, I)))
                {
                    Nacionalidad elemento = new Nacionalidad();
                    try
                    {
                        elemento.id_naci = int.Parse(id_naci);
                    }
                    catch
                    {
                        elemento.id_naci = 0;
                    }
                    elemento.nacionalidad = nacionalidad;
                    elemento.desc_nac = desc_nac;

                    elemento.eliminado = int.Parse(Eliminado) == 1 ? true : false;

                    int res = -1;

                    res = Logica.PutNacionalidades(elemento, iden);

                    return res != -2147483647 ? res.ToString() : L.ERR("LblGENUserNotAuthorized");
                }
                else
                {
                    throw new Exception(L.LBL("LblGENWrongUserSession"));
                }
            }
            catch (Exception ex)
            {
                #region Manejo de Errores (Administrador)

                var metodo = MethodBase.GetCurrentMethod().Name;
                var msgError = string.Format(MssgTrace.Trace_Message_Error, metodo, ex);
                LogGenie.ErrorLogSave(ex.Message, 16, msgError, System.Diagnostics.TraceEventType.Error);

                #endregion

                #region Manejo de Errores (Base de Datos)

                try
                {
                    var xException = new Excepcion
                    {
                        EventID = 0,
                        Priority = 16,
                        Severity = TraceEventType.Error,
                        Title = ex.Message,
                        Timestamp = DateTime.Now,
                        MachineName = Environment.MachineName,
                        AppDomainName = Environment.UserDomainName,
                        ProcessID = string.Empty,
                        ProcessName = Environment.CommandLine,
                        ThreadName = string.Empty,
                        Message = ex.ToString()
                    };

                    Logica logica = new Logica();
                    logica.DataBaseLogError(xException);
                }
                catch
                {
                }

                #endregion

                return "<p class=\"SevenMsgError\"><b>" + L.LBL("LblGENWrongQuery") + ":</b></br> " + L.ERR(ex.Message).Replace("[", "").Replace("]", "") + "</p>";
            }
        }


        #endregion

        #region Impuestos

        [WebGet]
        [OperationContract]
        public string GetImpuestos(string Eliminado, string Dominio, string U, string N, string D, string I, string LangCode)
        {
            try
            {
                Identidad iden = new Identidad(int.Parse(Enigma.Desencriptar(U)), Enigma.Desencriptar(N), int.Parse(Enigma.Desencriptar(D)), Enigma.Desencriptar(I));

                if ((Seguridad.CargarConfiguracionManagement() == 1) && (Seguridad.VerificarSesion(U, N, 1, D, I)))
                {
                    bool Eliminados = false;
                    try
                    {
                        Eliminados = int.Parse(Eliminado) == 0 ? false : true;
                    }
                    catch { }

                    Impuesto elemento = new Impuesto();
                    elemento.id_impu = 0;

                    return Globals.jqGridGenie.DataTableToJQGridJSON(Logica.GetImpuestos(elemento, Eliminados, iden));
                }
                else
                {
                    throw new Exception(L.LBL("LblGENWrongUserSession"));
                }
            }
            catch (Exception ex)
            {
                #region Manejo de Errores (Administrador)

                var metodo = MethodBase.GetCurrentMethod().Name;
                var msgError = string.Format(MssgTrace.Trace_Message_Error, metodo, ex);
                LogGenie.ErrorLogSave(ex.Message, 16, msgError, System.Diagnostics.TraceEventType.Error);

                #endregion

                #region Manejo de Errores (Base de Datos)

                try
                {
                    var xException = new Excepcion
                    {
                        EventID = 0,
                        Priority = 16,
                        Severity = TraceEventType.Error,
                        Title = ex.Message,
                        Timestamp = DateTime.Now,
                        MachineName = Environment.MachineName,
                        AppDomainName = Environment.UserDomainName,
                        ProcessID = string.Empty,
                        ProcessName = Environment.CommandLine,
                        ThreadName = string.Empty,
                        Message = ex.ToString()
                    };

                    Logica logica = new Logica();
                    logica.DataBaseLogError(xException);
                }
                catch
                {
                }

                #endregion

                return "<p class=\"SevenMsgError\"><b>" + L.LBL("LblGENWrongQuery") + ":</b></br> " + L.ERR(ex.Message).Replace("[", "").Replace("]", "") + "</p>";
            }
        }

        [WebGet]
        [OperationContract]
        public string PutImpuestos(string id_impu, string desc_impu, string porc_impu, string afecta_cange, string nivel, string apli_sup, string Eliminado, string U, string N, string D, string I, string LangCode)
        {
            try
            {
                Identidad iden = new Identidad(int.Parse(Enigma.Desencriptar(U)), Enigma.Desencriptar(N), int.Parse(Enigma.Desencriptar(D)), Enigma.Desencriptar(I));

                if ((Seguridad.CargarConfiguracionManagement() == 1) && (Seguridad.VerificarSesion(U, N, 1, D, I)))
                {
                    Impuesto elemento = new Impuesto();
                    try
                    {
                        elemento.id_impu = int.Parse(id_impu);
                    }
                    catch
                    {
                        elemento.id_impu = 0;
                    }

                    try
                    {
                        elemento.afecta_cange = int.Parse(afecta_cange) == 1 ? true : false;
                    }
                    catch
                    {
                        elemento.afecta_cange = false;
                    }

                    try
                    {
                        elemento.apli_sup = int.Parse(apli_sup) == 1 ? true : false;
                    }
                    catch
                    {
                        elemento.apli_sup = false;
                    }

                    elemento.desc_impu = desc_impu;

                    elemento.porc_impu = decimal.Parse(porc_impu);

                    elemento.nivel = int.Parse(nivel);

                    elemento.eliminado = int.Parse(Eliminado) == 1 ? true : false;

                    int res = -1;

                    res = Logica.PutImpuestos(elemento, iden);

                    return res != -2147483647 ? res.ToString() : L.ERR("LblGENUserNotAuthorized");
                }
                else
                {
                    throw new Exception(L.LBL("LblGENWrongUserSession"));
                }
            }
            catch (Exception ex)
            {
                #region Manejo de Errores (Administrador)

                var metodo = MethodBase.GetCurrentMethod().Name;
                var msgError = string.Format(MssgTrace.Trace_Message_Error, metodo, ex);
                LogGenie.ErrorLogSave(ex.Message, 16, msgError, System.Diagnostics.TraceEventType.Error);

                #endregion

                #region Manejo de Errores (Base de Datos)

                try
                {
                    var xException = new Excepcion
                    {
                        EventID = 0,
                        Priority = 16,
                        Severity = TraceEventType.Error,
                        Title = ex.Message,
                        Timestamp = DateTime.Now,
                        MachineName = Environment.MachineName,
                        AppDomainName = Environment.UserDomainName,
                        ProcessID = string.Empty,
                        ProcessName = Environment.CommandLine,
                        ThreadName = string.Empty,
                        Message = ex.ToString()
                    };

                    Logica logica = new Logica();
                    logica.DataBaseLogError(xException);
                }
                catch
                {
                }

                #endregion

                return "<p class=\"SevenMsgError\"><b>" + L.LBL("LblGENWrongQuery") + ":</b></br> " + L.ERR(ex.Message).Replace("[", "").Replace("]", "") + "</p>";
            }
        }


        #endregion

        #region Modulos

        [WebGet]
        [OperationContract]
        public string GetModulos(string Eliminado, string Dominio, string U, string N, string D, string I, string LangCode)
        {
            try
            {
                Identidad iden = new Identidad(int.Parse(Enigma.Desencriptar(U)), Enigma.Desencriptar(N), int.Parse(Enigma.Desencriptar(D)), Enigma.Desencriptar(I));

                if ((Seguridad.CargarConfiguracionManagement() == 1) && (Seguridad.VerificarSesion(U, N, 1, D, I)))
                {
                    bool Eliminados = false;
                    try
                    {
                        Eliminados = int.Parse(Eliminado) == 0 ? false : true;
                    }
                    catch { }

                    Modulo elemento = new Modulo();
                    elemento.id_modulo = 0;

                    return Globals.jqGridGenie.DataTableToJQGridJSON(Logica.GetModulos(elemento, Eliminados, iden));
                }
                else
                {
                    throw new Exception(L.LBL("LblGENWrongUserSession"));
                }
            }
            catch (Exception ex)
            {
                #region Manejo de Errores (Administrador)

                var metodo = MethodBase.GetCurrentMethod().Name;
                var msgError = string.Format(MssgTrace.Trace_Message_Error, metodo, ex);
                LogGenie.ErrorLogSave(ex.Message, 16, msgError, System.Diagnostics.TraceEventType.Error);

                #endregion

                #region Manejo de Errores (Base de Datos)

                try
                {
                    var xException = new Excepcion
                    {
                        EventID = 0,
                        Priority = 16,
                        Severity = TraceEventType.Error,
                        Title = ex.Message,
                        Timestamp = DateTime.Now,
                        MachineName = Environment.MachineName,
                        AppDomainName = Environment.UserDomainName,
                        ProcessID = string.Empty,
                        ProcessName = Environment.CommandLine,
                        ThreadName = string.Empty,
                        Message = ex.ToString()
                    };

                    Logica logica = new Logica();
                    logica.DataBaseLogError(xException);
                }
                catch
                {
                }

                #endregion

                return "<p class=\"SevenMsgError\"><b>" + L.LBL("LblGENWrongQuery") + ":</b></br> " + L.ERR(ex.Message).Replace("[", "").Replace("]", "") + "</p>";
            }
        }

        [WebGet]
        [OperationContract]
        public string PutModulos(string id_modulo, string desc_modulo, string conexion, string base_datos, string activo, string Eliminado, string U, string N, string D, string I, string LangCode)
        {
            try
            {
                Identidad iden = new Identidad(int.Parse(Enigma.Desencriptar(U)), Enigma.Desencriptar(N), int.Parse(Enigma.Desencriptar(D)), Enigma.Desencriptar(I));

                if ((Seguridad.CargarConfiguracionManagement() == 1) && (Seguridad.VerificarSesion(U, N, 1, D, I)))
                {
                    Modulo elemento = new Modulo();
                    try
                    {
                        elemento.id_modulo = int.Parse(id_modulo);
                    }
                    catch
                    {
                        elemento.id_modulo = 0;
                    }
                    elemento.desc_modulo = desc_modulo;
                    elemento.conexion = conexion;
                    elemento.base_datos = base_datos;
                    elemento.activo = bool.Parse(activo);


                    //elemento.eliminado = int.Parse(Eliminado) == 1 ? true : false;

                    int res = -1;

                    res = Logica.PutModulos(elemento, iden);

                    return res != -2147483647 ? res.ToString() : L.ERR("LblGENUserNotAuthorized");
                }
                else
                {
                    throw new Exception(L.LBL("LblGENWrongUserSession"));
                }
            }
            catch (Exception ex)
            {
                #region Manejo de Errores (Administrador)

                var metodo = MethodBase.GetCurrentMethod().Name;
                var msgError = string.Format(MssgTrace.Trace_Message_Error, metodo, ex);
                LogGenie.ErrorLogSave(ex.Message, 16, msgError, System.Diagnostics.TraceEventType.Error);

                #endregion

                #region Manejo de Errores (Base de Datos)

                try
                {
                    var xException = new Excepcion
                    {
                        EventID = 0,
                        Priority = 16,
                        Severity = TraceEventType.Error,
                        Title = ex.Message,
                        Timestamp = DateTime.Now,
                        MachineName = Environment.MachineName,
                        AppDomainName = Environment.UserDomainName,
                        ProcessID = string.Empty,
                        ProcessName = Environment.CommandLine,
                        ThreadName = string.Empty,
                        Message = ex.ToString()
                    };

                    Logica logica = new Logica();
                    logica.DataBaseLogError(xException);
                }
                catch
                {
                }

                #endregion

                return "<p class=\"SevenMsgError\"><b>" + L.LBL("LblGENWrongQuery") + ":</b></br> " + L.ERR(ex.Message).Replace("[", "").Replace("]", "") + "</p>";
            }
        }
        
        #endregion

        #region Aplicaciones

        [WebGet]
        [OperationContract]
        public string GetAplicaciones(string Eliminado, string Dominio, string U, string N, string D, string I, string LangCode)
        {
            try
            {
                Identidad iden = new Identidad(int.Parse(Enigma.Desencriptar(U)), Enigma.Desencriptar(N), int.Parse(Enigma.Desencriptar(D)), Enigma.Desencriptar(I));

                if ((Seguridad.CargarConfiguracionManagement() == 1) && (Seguridad.VerificarSesion(U, N, 1, D, I)))
                {
                    bool Eliminados = false;
                    //try
                    //{
                    //    Eliminados = int.Parse(Eliminado) == 0 ? false : true;
                    //}
                    //catch { }

                    Aplicacion elemento = new Aplicacion();
                    elemento.id_app = Int32.Parse(Eliminado);


                    return Globals.jqGridGenie.DataTableToJQGridJSON(Logica.GetAplicaciones(elemento, Eliminados, iden));
                }
                else
                {
                    throw new Exception(L.LBL("LblGENWrongUserSession"));
                }
            }
            catch (Exception ex)
            {
                #region Manejo de Errores (Administrador)

                var metodo = MethodBase.GetCurrentMethod().Name;
                var msgError = string.Format(MssgTrace.Trace_Message_Error, metodo, ex);
                LogGenie.ErrorLogSave(ex.Message, 16, msgError, System.Diagnostics.TraceEventType.Error);

                #endregion

                #region Manejo de Errores (Base de Datos)

                try
                {
                    var xException = new Excepcion
                    {
                        EventID = 0,
                        Priority = 16,
                        Severity = TraceEventType.Error,
                        Title = ex.Message,
                        Timestamp = DateTime.Now,
                        MachineName = Environment.MachineName,
                        AppDomainName = Environment.UserDomainName,
                        ProcessID = string.Empty,
                        ProcessName = Environment.CommandLine,
                        ThreadName = string.Empty,
                        Message = ex.ToString()
                    };

                    Logica logica = new Logica();
                    logica.DataBaseLogError(xException);
                }
                catch
                {
                }

                #endregion

                return "<p class=\"SevenMsgError\"><b>" + L.LBL("LblGENWrongQuery") + ":</b></br> " + L.ERR(ex.Message).Replace("[", "").Replace("]", "") + "</p>";
            }
        }

        [WebGet]
        [OperationContract]
        public string PutAplicaciones(string id_app, string id_modulo, string desc_app, string U, string N, string D, string I, string LangCode)
        {
            try
            {
                Identidad iden = new Identidad(int.Parse(Enigma.Desencriptar(U)), Enigma.Desencriptar(N), int.Parse(Enigma.Desencriptar(D)), Enigma.Desencriptar(I));

                if ((Seguridad.CargarConfiguracionManagement() == 1) && (Seguridad.VerificarSesion(U, N, 1, D, I)))
                {
                    Aplicacion elemento = new Aplicacion();
                    try
                    {
                        elemento.id_app = int.Parse(id_app);
                    }
                    catch
                    {
                        elemento.id_app = 0;
                    }
                    elemento.id_modulo = int.Parse(id_modulo);
                    elemento.desc_app = desc_app;

                    int res = -1;

                    res = Logica.PutAplicaciones(elemento, iden);

                    return res != -2147483647 ? res.ToString() : L.ERR("LblGENUserNotAuthorized");
                }
                else
                {
                    throw new Exception(L.LBL("LblGENWrongUserSession"));
                }
            }
            catch (Exception ex)
            {
                #region Manejo de Errores (Administrador)

                var metodo = MethodBase.GetCurrentMethod().Name;
                var msgError = string.Format(MssgTrace.Trace_Message_Error, metodo, ex);
                LogGenie.ErrorLogSave(ex.Message, 16, msgError, System.Diagnostics.TraceEventType.Error);

                #endregion

                #region Manejo de Errores (Base de Datos)

                try
                {
                    var xException = new Excepcion
                    {
                        EventID = 0,
                        Priority = 16,
                        Severity = TraceEventType.Error,
                        Title = ex.Message,
                        Timestamp = DateTime.Now,
                        MachineName = Environment.MachineName,
                        AppDomainName = Environment.UserDomainName,
                        ProcessID = string.Empty,
                        ProcessName = Environment.CommandLine,
                        ThreadName = string.Empty,
                        Message = ex.ToString()
                    };

                    Logica logica = new Logica();
                    logica.DataBaseLogError(xException);
                }
                catch
                {
                }

                #endregion

                return "<p class=\"SevenMsgError\"><b>" + L.LBL("LblGENWrongQuery") + ":</b></br> " + L.ERR(ex.Message).Replace("[", "").Replace("]", "") + "</p>";
            }
        }

        [WebGet]
        [OperationContract]
        public string GetSelectAplicaciones(string Id, string Dominio, string U, string N, string D, string I, string LangCode)
        {
            try
            {
                Identidad iden = new Identidad(int.Parse(Enigma.Desencriptar(U)), Enigma.Desencriptar(N), int.Parse(Enigma.Desencriptar(D)), Enigma.Desencriptar(I));

                if ((Seguridad.CargarConfiguracionManagement() == 1) && (Seguridad.VerificarSesion(U, N, 1, D, I)))
                {
                    return Globals.jqGridGenie.DataTableToJQGridJSON(HTMLSelects.Get_AplicacionesCombo_JQ(Id));
                    //return Globals.jqGridGenie.DataTableToJQGridJSON(Logica.GetAplicaciones(elemento, Eliminados, iden));
                }
                else
                {
                    throw new Exception(L.LBL("LblGENWrongUserSession"));
                }
            }
            catch (Exception ex)
            {
                #region Manejo de Errores (Administrador)

                var metodo = MethodBase.GetCurrentMethod().Name;
                var msgError = string.Format(MssgTrace.Trace_Message_Error, metodo, ex);
                LogGenie.ErrorLogSave(ex.Message, 16, msgError, System.Diagnostics.TraceEventType.Error);

                #endregion

                #region Manejo de Errores (Base de Datos)

                try
                {
                    var xException = new Excepcion
                    {
                        EventID = 0,
                        Priority = 16,
                        Severity = TraceEventType.Error,
                        Title = ex.Message,
                        Timestamp = DateTime.Now,
                        MachineName = Environment.MachineName,
                        AppDomainName = Environment.UserDomainName,
                        ProcessID = string.Empty,
                        ProcessName = Environment.CommandLine,
                        ThreadName = string.Empty,
                        Message = ex.ToString()
                    };

                    Logica logica = new Logica();
                    logica.DataBaseLogError(xException);
                }
                catch
                {
                }

                #endregion

                return "<p class=\"SevenMsgError\"><b>" + L.LBL("LblGENWrongQuery") + ":</b></br> " + L.ERR(ex.Message).Replace("[", "").Replace("]", "") + "</p>";
            }
        }

        #endregion

        #region Opciones

        [WebGet]
        [OperationContract]
        public string GetOpciones(string Eliminado, string Dominio, string U, string N, string D, string I, string LangCode)
        {
            try
            {
                Identidad iden = new Identidad(int.Parse(Enigma.Desencriptar(U)), Enigma.Desencriptar(N), int.Parse(Enigma.Desencriptar(D)), Enigma.Desencriptar(I));

                if ((Seguridad.CargarConfiguracionManagement() == 1) && (Seguridad.VerificarSesion(U, N, 1, D, I)))
                {
                    bool Eliminados = false;
                    //try
                    //{
                    //    Eliminados = int.Parse(Eliminado) == 0 ? false : true;
                    //}
                    //catch { }

                    Opcion elemento = new Opcion();
                    elemento.id_opc = Int32.Parse(Eliminado);

                    return Globals.jqGridGenie.DataTableToJQGridJSON(Logica.GetOpciones(elemento, Eliminados, iden));
                }
                else
                {
                    throw new Exception(L.LBL("LblGENWrongUserSession"));
                }
            }
            catch (Exception ex)
            {
                #region Manejo de Errores (Administrador)

                var metodo = MethodBase.GetCurrentMethod().Name;
                var msgError = string.Format(MssgTrace.Trace_Message_Error, metodo, ex);
                LogGenie.ErrorLogSave(ex.Message, 16, msgError, System.Diagnostics.TraceEventType.Error);

                #endregion

                #region Manejo de Errores (Base de Datos)

                try
                {
                    var xException = new Excepcion
                    {
                        EventID = 0,
                        Priority = 16,
                        Severity = TraceEventType.Error,
                        Title = ex.Message,
                        Timestamp = DateTime.Now,
                        MachineName = Environment.MachineName,
                        AppDomainName = Environment.UserDomainName,
                        ProcessID = string.Empty,
                        ProcessName = Environment.CommandLine,
                        ThreadName = string.Empty,
                        Message = ex.ToString()
                    };

                    Logica logica = new Logica();
                    logica.DataBaseLogError(xException);
                }
                catch
                {
                }

                #endregion

                return "<p class=\"SevenMsgError\"><b>" + L.LBL("LblGENWrongQuery") + ":</b></br> " + L.ERR(ex.Message).Replace("[", "").Replace("]", "") + "</p>";
            }
        }

        [WebGet]
        [OperationContract]
        public string PutOpciones(string id_opc, string id_app, string desc_opc, string va_log_sheet, string id_parent, string historico, string Eliminado, string U, string N, string D, string I, string LangCode)
        {
            try
            {
                Identidad iden = new Identidad(int.Parse(Enigma.Desencriptar(U)), Enigma.Desencriptar(N), int.Parse(Enigma.Desencriptar(D)), Enigma.Desencriptar(I));

                if ((Seguridad.CargarConfiguracionManagement() == 1) && (Seguridad.VerificarSesion(U, N, 1, D, I)))
                {
                    Opcion elemento = new Opcion();
                    try
                    {
                        elemento.id_opc = int.Parse(id_opc);
                    }
                    catch
                    {
                        elemento.id_opc = 0;
                    }
                    try
                    {
                        elemento.va_log_sheet = int.Parse(va_log_sheet) == 1 ? true : false;
                    }
                    catch
                    {
                        elemento.va_log_sheet = false;
                    }
                    try
                    {
                        elemento.historico = int.Parse(historico) == 1 ? true : false;
                    }
                    catch
                    {
                        elemento.historico = false;
                    }
                    try
                    {
                        elemento.id_parent = int.Parse(id_parent);
                    }
                    catch
                    {
                        elemento.id_parent = 0;
                    }

                    elemento.id_app = int.Parse(id_app);
                    elemento.desc_opc = desc_opc;

                    //elemento.eliminado = int.Parse(Eliminado) == 1 ? true : false;

                    int res = -1;

                    res = Logica.PutOpciones(elemento, iden);

                    return res != -2147483647 ? res.ToString() : L.ERR("LblGENUserNotAuthorized");
                }
                else
                {
                    throw new Exception(L.LBL("LblGENWrongUserSession"));
                }
            }
            catch (Exception ex)
            {
                #region Manejo de Errores (Administrador)

                var metodo = MethodBase.GetCurrentMethod().Name;
                var msgError = string.Format(MssgTrace.Trace_Message_Error, metodo, ex);
                LogGenie.ErrorLogSave(ex.Message, 16, msgError, System.Diagnostics.TraceEventType.Error);

                #endregion

                #region Manejo de Errores (Base de Datos)

                try
                {
                    var xException = new Excepcion
                    {
                        EventID = 0,
                        Priority = 16,
                        Severity = TraceEventType.Error,
                        Title = ex.Message,
                        Timestamp = DateTime.Now,
                        MachineName = Environment.MachineName,
                        AppDomainName = Environment.UserDomainName,
                        ProcessID = string.Empty,
                        ProcessName = Environment.CommandLine,
                        ThreadName = string.Empty,
                        Message = ex.ToString()
                    };

                    Logica logica = new Logica();
                    logica.DataBaseLogError(xException);
                }
                catch
                {
                }

                #endregion

                return "<p class=\"SevenMsgError\"><b>" + L.LBL("LblGENWrongQuery") + ":</b></br> " + L.ERR(ex.Message).Replace("[", "").Replace("]", "") + "</p>";
            }
        }

        [WebGet]
        [OperationContract]
        public string GetSelectOpciones(string Id, string Dominio, string U, string N, string D, string I, string LangCode)
        {
            try
            {
                Identidad iden = new Identidad(int.Parse(Enigma.Desencriptar(U)), Enigma.Desencriptar(N), int.Parse(Enigma.Desencriptar(D)), Enigma.Desencriptar(I));

                if ((Seguridad.CargarConfiguracionManagement() == 1) && (Seguridad.VerificarSesion(U, N, 1, D, I)))
                {
                    return Globals.jqGridGenie.DataTableToJQGridJSON(HTMLSelects.Get_OpcionesCombo_JQ(Id));
                    //return Globals.jqGridGenie.DataTableToJQGridJSON(Logica.GetAplicaciones(elemento, Eliminados, iden));
                }
                else
                {
                    throw new Exception(L.LBL("LblGENWrongUserSession"));
                }
            }
            catch (Exception ex)
            {
                #region Manejo de Errores (Administrador)

                var metodo = MethodBase.GetCurrentMethod().Name;
                var msgError = string.Format(MssgTrace.Trace_Message_Error, metodo, ex);
                LogGenie.ErrorLogSave(ex.Message, 16, msgError, System.Diagnostics.TraceEventType.Error);

                #endregion

                #region Manejo de Errores (Base de Datos)

                try
                {
                    var xException = new Excepcion
                    {
                        EventID = 0,
                        Priority = 16,
                        Severity = TraceEventType.Error,
                        Title = ex.Message,
                        Timestamp = DateTime.Now,
                        MachineName = Environment.MachineName,
                        AppDomainName = Environment.UserDomainName,
                        ProcessID = string.Empty,
                        ProcessName = Environment.CommandLine,
                        ThreadName = string.Empty,
                        Message = ex.ToString()
                    };

                    Logica logica = new Logica();
                    logica.DataBaseLogError(xException);
                }
                catch
                {
                }

                #endregion

                return "<p class=\"SevenMsgError\"><b>" + L.LBL("LblGENWrongQuery") + ":</b></br> " + L.ERR(ex.Message).Replace("[", "").Replace("]", "") + "</p>";
            }
        }

        #endregion

        #region Accesos por Opcion

        [WebGet]
        [OperationContract]
        public string GetAcceso(string Opcion, string Dominio, string U, string N, string D, string I, string LangCode)
        {
            try
            {
                Identidad iden = new Identidad(int.Parse(Enigma.Desencriptar(U)), Enigma.Desencriptar(N), int.Parse(Enigma.Desencriptar(D)), Enigma.Desencriptar(I));

                if ((Seguridad.CargarConfiguracionManagement() == 1) && (Seguridad.VerificarSesion(U, N, 1, D, I)))
                {

                    Opcion elemento = new Opcion();

                    try
                    {
                        elemento.id_opc = Int32.Parse(Opcion);
                    }
                    catch
                    {
                        elemento.id_opc = 0;
                    }
                    

                    return Globals.jqGridGenie.DataTableToJQGridJSON(Logica.GetAcceso(elemento, iden));
                }
                else
                {
                    throw new Exception(L.LBL("LblGENWrongUserSession"));
                }
            }
            catch (Exception ex)
            {
                #region Manejo de Errores (Administrador)

                var metodo = MethodBase.GetCurrentMethod().Name;
                var msgError = string.Format(MssgTrace.Trace_Message_Error, metodo, ex);
                LogGenie.ErrorLogSave(ex.Message, 16, msgError, System.Diagnostics.TraceEventType.Error);

                #endregion

                #region Manejo de Errores (Base de Datos)

                try
                {
                    var xException = new Excepcion
                    {
                        EventID = 0,
                        Priority = 16,
                        Severity = TraceEventType.Error,
                        Title = ex.Message,
                        Timestamp = DateTime.Now,
                        MachineName = Environment.MachineName,
                        AppDomainName = Environment.UserDomainName,
                        ProcessID = string.Empty,
                        ProcessName = Environment.CommandLine,
                        ThreadName = string.Empty,
                        Message = ex.ToString()
                    };

                    Logica logica = new Logica();
                    logica.DataBaseLogError(xException);
                }
                catch
                {
                }

                #endregion

                return "<p class=\"SevenMsgError\"><b>" + L.LBL("LblGENWrongQuery") + ":</b></br> " + L.ERR(ex.Message).Replace("[", "").Replace("]", "") + "</p>";
            }
        }

        #endregion

        #region Enlace entre Modulos

        [WebGet]
        [OperationContract]
        public string GetEnlace(string Eliminado, string Dominio, string U, string N, string D, string I, string LangCode)
        {
            try
            {
                Identidad iden = new Identidad(int.Parse(Enigma.Desencriptar(U)), Enigma.Desencriptar(N), int.Parse(Enigma.Desencriptar(D)), Enigma.Desencriptar(I));

                if ((Seguridad.CargarConfiguracionManagement() == 1) && (Seguridad.VerificarSesion(U, N, 1, D, I)))
                {
                    bool Eliminados = false;
                    try
                    {
                        Eliminados = int.Parse(Eliminado) == 0 ? false : true;
                    }
                    catch { }

                    Enlace elemento = new Enlace();
                    elemento.id_enla_datos = 0;

                    return Globals.jqGridGenie.DataTableToJQGridJSON(Logica.GetEnlace(elemento, Eliminados, iden));
                }
                else
                {
                    throw new Exception(L.LBL("LblGENWrongUserSession"));
                }
            }
            catch (Exception ex)
            {
                #region Manejo de Errores (Administrador)

                var metodo = MethodBase.GetCurrentMethod().Name;
                var msgError = string.Format(MssgTrace.Trace_Message_Error, metodo, ex);
                LogGenie.ErrorLogSave(ex.Message, 16, msgError, System.Diagnostics.TraceEventType.Error);

                #endregion

                #region Manejo de Errores (Base de Datos)

                try
                {
                    var xException = new Excepcion
                    {
                        EventID = 0,
                        Priority = 16,
                        Severity = TraceEventType.Error,
                        Title = ex.Message,
                        Timestamp = DateTime.Now,
                        MachineName = Environment.MachineName,
                        AppDomainName = Environment.UserDomainName,
                        ProcessID = string.Empty,
                        ProcessName = Environment.CommandLine,
                        ThreadName = string.Empty,
                        Message = ex.ToString()
                    };

                    Logica logica = new Logica();
                    logica.DataBaseLogError(xException);
                }
                catch
                {
                }

                #endregion

                return "<p class=\"SevenMsgError\"><b>" + L.LBL("LblGENWrongQuery") + ":</b></br> " + L.ERR(ex.Message).Replace("[", "").Replace("]", "") + "</p>";
            }
        }

        [WebGet]
        [OperationContract]
        public string Get_BasesEnlaceCombo(string Dominio, string U, string N, string D, string I, string LangCode)
        {
            try
            {
                Identidad iden = new Identidad(int.Parse(Enigma.Desencriptar(U)), Enigma.Desencriptar(N), int.Parse(Enigma.Desencriptar(D)), Enigma.Desencriptar(I));

                if ((Seguridad.CargarConfiguracionManagement() == 1) && (Seguridad.VerificarSesion(U, N, 1, D, I)))
                {
                    return Globals.jqGridGenie.DataTableToJQGridCombo(HTMLSelects.Get_BasesEnlaceCombo_JQ());
                }
                else
                {
                    throw new Exception(L.LBL("LblGENWrongUserSession"));
                }
            }
            catch (Exception ex)
            {
                #region Manejo de Errores (Administrador)

                var metodo = MethodBase.GetCurrentMethod().Name;
                var msgError = string.Format(MssgTrace.Trace_Message_Error, metodo, ex);
                LogGenie.ErrorLogSave(ex.Message, 16, msgError, System.Diagnostics.TraceEventType.Error);

                #endregion

                #region Manejo de Errores (Base de Datos)

                try
                {
                    var xException = new Excepcion
                    {
                        EventID = 0,
                        Priority = 16,
                        Severity = TraceEventType.Error,
                        Title = ex.Message,
                        Timestamp = DateTime.Now,
                        MachineName = Environment.MachineName,
                        AppDomainName = Environment.UserDomainName,
                        ProcessID = string.Empty,
                        ProcessName = Environment.CommandLine,
                        ThreadName = string.Empty,
                        Message = ex.ToString()
                    };

                    Logica logica = new Logica();
                    logica.DataBaseLogError(xException);
                }
                catch
                {
                }

                #endregion

                return "<p class=\"SevenMsgError\"><b>" + L.LBL("LblGENWrongQuery") + ":</b></br> " + L.ERR(ex.Message).Replace("[", "").Replace("]", "") + "</p>";
            }
        }

        [WebGet]
        [OperationContract]
        public string PutEnlace(string id_enla_datos, string id_datos_origen, string id_datos_destino, string Eliminado, string U, string N, string D, string I, string LangCode)
        {
            try
            {
                Identidad iden = new Identidad(int.Parse(Enigma.Desencriptar(U)), Enigma.Desencriptar(N), int.Parse(Enigma.Desencriptar(D)), Enigma.Desencriptar(I));

                if ((Seguridad.CargarConfiguracionManagement() == 1) && (Seguridad.VerificarSesion(U, N, 1, D, I)))
                {
                    Enlace elemento = new Enlace();
                    try
                    {
                        elemento.id_enla_datos = int.Parse(id_enla_datos);
                    }
                    catch
                    {
                        elemento.id_enla_datos = 0;
                    }

                    try
                    {
                        elemento.eliminado = int.Parse(Eliminado);
                    }
                    catch
                    {
                        elemento.eliminado = 0;
                    }

                    elemento.id_datos_origen = int.Parse(id_datos_origen);
                    elemento.id_datos_destino = int.Parse(id_datos_destino);
                    

                    int res = -1;

                    res = Logica.PutEnlace(elemento, iden);

                    return res != -2147483647 ? res.ToString() : L.ERR("LblGENUserNotAuthorized");
                }
                else
                {
                    throw new Exception(L.LBL("LblGENWrongUserSession"));
                }
            }
            catch (Exception ex)
            {
                #region Manejo de Errores (Administrador)

                var metodo = MethodBase.GetCurrentMethod().Name;
                var msgError = string.Format(MssgTrace.Trace_Message_Error, metodo, ex);
                LogGenie.ErrorLogSave(ex.Message, 16, msgError, System.Diagnostics.TraceEventType.Error);

                #endregion

                #region Manejo de Errores (Base de Datos)

                try
                {
                    var xException = new Excepcion
                    {
                        EventID = 0,
                        Priority = 16,
                        Severity = TraceEventType.Error,
                        Title = ex.Message,
                        Timestamp = DateTime.Now,
                        MachineName = Environment.MachineName,
                        AppDomainName = Environment.UserDomainName,
                        ProcessID = string.Empty,
                        ProcessName = Environment.CommandLine,
                        ThreadName = string.Empty,
                        Message = ex.ToString()
                    };

                    Logica logica = new Logica();
                    logica.DataBaseLogError(xException);
                }
                catch
                {
                }

                #endregion

                return "<p class=\"SevenMsgError\"><b>" + L.LBL("LblGENWrongQuery") + ":</b></br> " + L.ERR(ex.Message).Replace("[", "").Replace("]", "") + "</p>";
            }
        }

        [WebGet]
        [OperationContract]
        public string PutEnlace_Entre_Bases(string id_enla_datos, string id_datos_origen, string id_datos_destino, string Eliminado, string U, string N, string D, string I, string LangCode)
        {
            try
            {
                Identidad iden = new Identidad(int.Parse(Enigma.Desencriptar(U)), Enigma.Desencriptar(N), int.Parse(Enigma.Desencriptar(D)), Enigma.Desencriptar(I));

                if ((Seguridad.CargarConfiguracionManagement() == 1) && (Seguridad.VerificarSesion(U, N, 1, D, I)))
                {
                    Enlace elemento = new Enlace();
                    try
                    {
                        elemento.id_enla_datos = int.Parse(id_enla_datos);
                    }
                    catch
                    {
                        elemento.id_enla_datos = 0;
                    }

                    try
                    {
                        elemento.eliminado = int.Parse(Eliminado);
                    }
                    catch
                    {
                        elemento.eliminado = 0;
                    }

                    elemento.id_datos_origen = int.Parse(id_datos_origen);
                    elemento.id_datos_destino = int.Parse(id_datos_destino);


                    int res = -1;

                    res = Logica.PutEnlace_Entre_Bases(elemento, iden);

                    return res != -2147483647 ? res.ToString() : L.ERR("LblGENUserNotAuthorized");
                }
                else
                {
                    throw new Exception(L.LBL("LblGENWrongUserSession"));
                }
            }
            catch (Exception ex)
            {
                #region Manejo de Errores (Administrador)

                var metodo = MethodBase.GetCurrentMethod().Name;
                var msgError = string.Format(MssgTrace.Trace_Message_Error, metodo, ex);
                LogGenie.ErrorLogSave(ex.Message, 16, msgError, System.Diagnostics.TraceEventType.Error);

                #endregion

                #region Manejo de Errores (Base de Datos)

                try
                {
                    var xException = new Excepcion
                    {
                        EventID = 0,
                        Priority = 16,
                        Severity = TraceEventType.Error,
                        Title = ex.Message,
                        Timestamp = DateTime.Now,
                        MachineName = Environment.MachineName,
                        AppDomainName = Environment.UserDomainName,
                        ProcessID = string.Empty,
                        ProcessName = Environment.CommandLine,
                        ThreadName = string.Empty,
                        Message = ex.ToString()
                    };

                    Logica logica = new Logica();
                    logica.DataBaseLogError(xException);
                }
                catch
                {
                }

                #endregion

                return "<p class=\"SevenMsgError\"><b>" + L.LBL("LblGENWrongQuery") + ":</b></br> " + L.ERR(ex.Message).Replace("[", "").Replace("]", "") + "</p>";
            }
        }


        #endregion

        #region Servidores Servicios

        [WebGet]
        [OperationContract]
        public string GetServidorServicio(string Eliminado, string Dominio, string U, string N, string D, string I, string LangCode)
        {
            try
            {
                Identidad iden = new Identidad(int.Parse(Enigma.Desencriptar(U)), Enigma.Desencriptar(N), int.Parse(Enigma.Desencriptar(D)), Enigma.Desencriptar(I));

                if ((Seguridad.CargarConfiguracionManagement() == 1) && (Seguridad.VerificarSesion(U, N, 1, D, I)))
                {
                    bool Eliminados = false;
                    try
                    {
                        Eliminados = int.Parse(Eliminado) == 0 ? false : true;
                    }
                    catch { }

                    ServidorServicio elemento = new ServidorServicio();
                    elemento.id_server = 0;

                    return Globals.jqGridGenie.DataTableToJQGridJSON(Logica.GetServidorServicio(elemento, Eliminados, iden));
                }
                else
                {
                    throw new Exception(L.LBL("LblGENWrongUserSession"));
                }
            }
            catch (Exception ex)
            {
                #region Manejo de Errores (Administrador)

                var metodo = MethodBase.GetCurrentMethod().Name;
                var msgError = string.Format(MssgTrace.Trace_Message_Error, metodo, ex);
                LogGenie.ErrorLogSave(ex.Message, 16, msgError, System.Diagnostics.TraceEventType.Error);

                #endregion

                #region Manejo de Errores (Base de Datos)

                try
                {
                    var xException = new Excepcion
                    {
                        EventID = 0,
                        Priority = 16,
                        Severity = TraceEventType.Error,
                        Title = ex.Message,
                        Timestamp = DateTime.Now,
                        MachineName = Environment.MachineName,
                        AppDomainName = Environment.UserDomainName,
                        ProcessID = string.Empty,
                        ProcessName = Environment.CommandLine,
                        ThreadName = string.Empty,
                        Message = ex.ToString()
                    };

                    Logica logica = new Logica();
                    logica.DataBaseLogError(xException);
                }
                catch
                {
                }

                #endregion

                return "<p class=\"SevenMsgError\"><b>" + L.LBL("LblGENWrongQuery") + ":</b></br> " + L.ERR(ex.Message).Replace("[", "").Replace("]", "") + "</p>";
            }
        }

        [WebGet]
        [OperationContract]
        public string PutServidorServicio(string id_server, string id_terminal, string descripcion, string remoteport, string Eliminado, string U, string N, string D, string I, string LangCode)
        {
            try
            {
                Identidad iden = new Identidad(int.Parse(Enigma.Desencriptar(U)), Enigma.Desencriptar(N), int.Parse(Enigma.Desencriptar(D)), Enigma.Desencriptar(I));

                if ((Seguridad.CargarConfiguracionManagement() == 1) && (Seguridad.VerificarSesion(U, N, 1, D, I)))
                {
                    ServidorServicio elemento = new ServidorServicio();
                    try
                    {
                        elemento.id_server = int.Parse(id_server);
                    }
                    catch
                    {
                        elemento.id_server = 0;
                    }

                    try
                    {
                        elemento.eliminado = int.Parse(Eliminado);
                    }
                    catch
                    {
                        elemento.eliminado = 0;
                    }

                    elemento.id_terminal = int.Parse(id_terminal);
                    elemento.descripcion = descripcion;
                    elemento.remoteport = int.Parse(remoteport);
                    elemento.eliminado = int.Parse(Eliminado);
                    

                    int res = -1;

                    res = Logica.PutServidorServicio(elemento, iden);

                    return res != -2147483647 ? res.ToString() : L.ERR("LblGENUserNotAuthorized");
                }
                else
                {
                    throw new Exception(L.LBL("LblGENWrongUserSession"));
                }
            }
            catch (Exception ex)
            {
                #region Manejo de Errores (Administrador)

                var metodo = MethodBase.GetCurrentMethod().Name;
                var msgError = string.Format(MssgTrace.Trace_Message_Error, metodo, ex);
                LogGenie.ErrorLogSave(ex.Message, 16, msgError, System.Diagnostics.TraceEventType.Error);

                #endregion

                #region Manejo de Errores (Base de Datos)

                try
                {
                    var xException = new Excepcion
                    {
                        EventID = 0,
                        Priority = 16,
                        Severity = TraceEventType.Error,
                        Title = ex.Message,
                        Timestamp = DateTime.Now,
                        MachineName = Environment.MachineName,
                        AppDomainName = Environment.UserDomainName,
                        ProcessID = string.Empty,
                        ProcessName = Environment.CommandLine,
                        ThreadName = string.Empty,
                        Message = ex.ToString()
                    };

                    Logica logica = new Logica();
                    logica.DataBaseLogError(xException);
                }
                catch
                {
                }

                #endregion

                return "<p class=\"SevenMsgError\"><b>" + L.LBL("LblGENWrongQuery") + ":</b></br> " + L.ERR(ex.Message).Replace("[", "").Replace("]", "") + "</p>";
            }
        }

        [WebGet]
        [OperationContract]
        public string GetServidor(string Eliminado, string Dominio, string U, string N, string D, string I, string LangCode)
        {
            try
            {
                Identidad iden = new Identidad(int.Parse(Enigma.Desencriptar(U)), Enigma.Desencriptar(N), int.Parse(Enigma.Desencriptar(D)), Enigma.Desencriptar(I));

                if ((Seguridad.CargarConfiguracionManagement() == 1) && (Seguridad.VerificarSesion(U, N, 1, D, I)))
                {
                    Servicio elemento = new Servicio();
                    elemento.id_server = 0;

                    return Globals.jqGridGenie.DataTableToJQGridJSON(Logica.GetServidor( elemento, false, iden));
                }
                else
                {
                    throw new Exception(L.LBL("LblGENWrongUserSession"));
                }
            }
            catch (Exception ex)
            {
                #region Manejo de Errores (Administrador)

                var metodo = MethodBase.GetCurrentMethod().Name;
                var msgError = string.Format(MssgTrace.Trace_Message_Error, metodo, ex);
                LogGenie.ErrorLogSave(ex.Message, 16, msgError, System.Diagnostics.TraceEventType.Error);

                #endregion

                #region Manejo de Errores (Base de Datos)

                try
                {
                    var xException = new Excepcion
                    {
                        EventID = 0,
                        Priority = 16,
                        Severity = TraceEventType.Error,
                        Title = ex.Message,
                        Timestamp = DateTime.Now,
                        MachineName = Environment.MachineName,
                        AppDomainName = Environment.UserDomainName,
                        ProcessID = string.Empty,
                        ProcessName = Environment.CommandLine,
                        ThreadName = string.Empty,
                        Message = ex.ToString()
                    };

                    Logica logica = new Logica();
                    logica.DataBaseLogError(xException);
                }
                catch
                {
                }

                #endregion

                return "<p class=\"SevenMsgError\"><b>" + L.LBL("LblGENWrongQuery") + ":</b></br> " + L.ERR(ex.Message).Replace("[", "").Replace("]", "") + "</p>";
            }
        }

        [WebGet]
        [OperationContract]
        public string GetServicios(string Server, string Datos, string Dominio, string U, string N, string D, string I, string LangCode)
        {
            try
            {
                Identidad iden = new Identidad(int.Parse(Enigma.Desencriptar(U)), Enigma.Desencriptar(N), int.Parse(Enigma.Desencriptar(D)), Enigma.Desencriptar(I));

                if ((Seguridad.CargarConfiguracionManagement() == 1) && (Seguridad.VerificarSesion(U, N, 1, D, I)))
                {
                    Servicio elemento = new Servicio();

                    try
                    {
                        elemento.id_server = int.Parse(Server);
                    }
                    catch { }

                    try
                    {
                        elemento.id_datos = int.Parse(Datos);
                    }
                    catch { }
                    
                    return Globals.jqGridGenie.DataTableToJQGridJSON(Logica.GetServicios(elemento, false, iden));
                }
                else
                {
                    throw new Exception(L.LBL("LblGENWrongUserSession"));
                }
            }
            catch (Exception ex)
            {
                #region Manejo de Errores (Administrador)

                var metodo = MethodBase.GetCurrentMethod().Name;
                var msgError = string.Format(MssgTrace.Trace_Message_Error, metodo, ex);
                LogGenie.ErrorLogSave(ex.Message, 16, msgError, System.Diagnostics.TraceEventType.Error);

                #endregion

                #region Manejo de Errores (Base de Datos)

                try
                {
                    var xException = new Excepcion
                    {
                        EventID = 0,
                        Priority = 16,
                        Severity = TraceEventType.Error,
                        Title = ex.Message,
                        Timestamp = DateTime.Now,
                        MachineName = Environment.MachineName,
                        AppDomainName = Environment.UserDomainName,
                        ProcessID = string.Empty,
                        ProcessName = Environment.CommandLine,
                        ThreadName = string.Empty,
                        Message = ex.ToString()
                    };

                    Logica logica = new Logica();
                    logica.DataBaseLogError(xException);
                }
                catch
                {
                }

                #endregion

                return "<p class=\"SevenMsgError\"><b>" + L.LBL("LblGENWrongQuery") + ":</b></br> " + L.ERR(ex.Message).Replace("[", "").Replace("]", "") + "</p>";
            }
        }

        [WebGet]
        [OperationContract]
        public string PutServicios(string Server, string Datos, string Serv, string Auto, string Manual, string U, string N, string D, string I, string LangCode)
        {
            try
            {
                Identidad iden = new Identidad(int.Parse(Enigma.Desencriptar(U)), Enigma.Desencriptar(N), int.Parse(Enigma.Desencriptar(D)), Enigma.Desencriptar(I));

                if ((Seguridad.CargarConfiguracionManagement() == 1) && (Seguridad.VerificarSesion(U, N, 1, D, I)))
                {
                    Servicio elemento = new Servicio();

                    try
                    {
                        elemento.id_server = int.Parse(Server);
                    }
                    catch {}

                    try
                    {
                        elemento.id_datos = int.Parse(Datos);
                    }
                    catch {}

                    try
                    {
                        elemento.id_serv = int.Parse(Serv);
                    }
                    catch {}

                    try
                    {
                        elemento.automatico = int.Parse(Auto) == 1 ? true : false;
                    }
                    catch
                    {
                        elemento.automatico = false;
                    }

                    try
                    {
                        elemento.manual = int.Parse(Manual) == 1 ? true : false;
                    }
                    catch
                    {
                        elemento.manual = false;
                    }

                    int res = -1;

                    res = Logica.PutServicios(elemento, iden);

                    return res != -2147483647 ? res.ToString() : L.ERR("LblGENUserNotAuthorized");
                }
                else
                {
                    throw new Exception(L.LBL("LblGENWrongUserSession"));
                }
            }
            catch (Exception ex)
            {
                #region Manejo de Errores (Administrador)

                var metodo = MethodBase.GetCurrentMethod().Name;
                var msgError = string.Format(MssgTrace.Trace_Message_Error, metodo, ex);
                LogGenie.ErrorLogSave(ex.Message, 16, msgError, System.Diagnostics.TraceEventType.Error);

                #endregion

                #region Manejo de Errores (Base de Datos)

                try
                {
                    var xException = new Excepcion
                    {
                        EventID = 0,
                        Priority = 16,
                        Severity = TraceEventType.Error,
                        Title = ex.Message,
                        Timestamp = DateTime.Now,
                        MachineName = Environment.MachineName,
                        AppDomainName = Environment.UserDomainName,
                        ProcessID = string.Empty,
                        ProcessName = Environment.CommandLine,
                        ThreadName = string.Empty,
                        Message = ex.ToString()
                    };

                    Logica logica = new Logica();
                    logica.DataBaseLogError(xException);
                }
                catch
                {
                }

                #endregion

                return "<p class=\"SevenMsgError\"><b>" + L.LBL("LblGENWrongQuery") + ":</b></br> " + L.ERR(ex.Message).Replace("[", "").Replace("]", "") + "</p>";
            }
        }

        #endregion

        #region Usuario

        [WebGet]
        [OperationContract]
        public string GetUsuario(string Usuario, string Activo, string Clave, string Vence, string Pagina, string Dominio, string U, string N, string D, string I, string LangCode)
        {
            try
            {
                Identidad iden = new Identidad(int.Parse(Enigma.Desencriptar(U)), Enigma.Desencriptar(N), int.Parse(Enigma.Desencriptar(D)), Enigma.Desencriptar(I));

                if ((Seguridad.CargarConfiguracionManagement() == 1) && (Seguridad.VerificarSesion(U, N, 1, D, I)))
                {
                    bool Usuarios = false;
                    bool Activos = false;
                    bool Claves = false;
                    bool Vences = false;
                    int vPagina = 0;

                    try
                    {
                        Usuarios = int.Parse(Usuario) == 0 ? false : true;
                    }
                    catch { }

                    try
                    {
                        Activos = int.Parse(Activo) == 0 ? false : true;
                    }
                    catch { }

                    try
                    {
                        Claves = int.Parse(Clave) == 0 ? false : true;
                    }
                    catch { }

                    try
                    {
                        Vences = int.Parse(Vence) == 0 ? false : true;
                    }
                    catch { }

                    try
                    {
                        vPagina = int.Parse(Pagina);
                    }
                    catch { }

                    Usuario elemento = new Usuario();
                    elemento.id_oper = 0;

                    return Globals.jqGridGenie.DataTableToJQGridJSON(Logica.GetUsuario(elemento, Usuarios, Activos, Claves, Vences, vPagina, iden));
                }
                else
                {
                    throw new Exception(L.LBL("LblGENWrongUserSession"));
                }
            }
            catch (Exception ex)
            {
                #region Manejo de Errores (Administrador)

                var metodo = MethodBase.GetCurrentMethod().Name;
                var msgError = string.Format(MssgTrace.Trace_Message_Error, metodo, ex);
                LogGenie.ErrorLogSave(ex.Message, 16, msgError, System.Diagnostics.TraceEventType.Error);

                #endregion

                #region Manejo de Errores (Base de Datos)

                try
                {
                    var xException = new Excepcion
                    {
                        EventID = 0,
                        Priority = 16,
                        Severity = TraceEventType.Error,
                        Title = ex.Message,
                        Timestamp = DateTime.Now,
                        MachineName = Environment.MachineName,
                        AppDomainName = Environment.UserDomainName,
                        ProcessID = string.Empty,
                        ProcessName = Environment.CommandLine,
                        ThreadName = string.Empty,
                        Message = ex.ToString()
                    };

                    Logica logica = new Logica();
                    logica.DataBaseLogError(xException);
                }
                catch
                {
                }

                #endregion

                return "<p class=\"SevenMsgError\"><b>" + L.LBL("LblGENWrongQuery") + ":</b></br> " + L.ERR(ex.Message).Replace("[", "").Replace("]", "") + "</p>";
            }
        }

        [WebGet]
        [OperationContract]
        public string PutUsuario(string id_oper, string nombre, string descripcion, string password, string fecha_creac, string fecha_clave, string dias_clave, string activo, string cambio_clave, string layout, string admin, string layout_acc, string layout_pos, string layout_inv, string layout_fa, string layout_pr, string clave_tarj, string Eliminado, string U, string N, string D, string I, string LangCode)
        {
            try
            {
                Identidad iden = new Identidad(int.Parse(Enigma.Desencriptar(U)), Enigma.Desencriptar(N), int.Parse(Enigma.Desencriptar(D)), Enigma.Desencriptar(I));

                if ((Seguridad.CargarConfiguracionManagement() == 1) && (Seguridad.VerificarSesion(U, N, 1, D, I)))
                {
                    Usuario elemento = new Usuario();
                    try
                    {
                        elemento.id_oper = int.Parse(id_oper);
                    }
                    catch
                    {
                        elemento.id_oper = 0;
                    }
                    
                    try
                    {
                        elemento.eliminado = int.Parse(Eliminado);
                    }
                    catch
                    {
                        elemento.eliminado = 0;
                    }

                    try
                    {
                        elemento.activo = int.Parse(activo) == 1 ? true : false;
                    }
                    catch
                    {
                        elemento.activo = false;
                    }

                    try
                    {
                        elemento.cambio_clave = int.Parse(cambio_clave) == 1 ? true : false;
                    }
                    catch
                    {
                        elemento.cambio_clave = false;
                    }

                    try
                    {
                        elemento.admin = int.Parse(admin) == 1 ? true : false;
                    }
                    catch
                    {
                        elemento.admin = false;
                    }

                    try
                    {
                        elemento.fecha_creac = DateTime.Parse(fecha_creac);
                    }
                    catch
                    {
                        elemento.fecha_creac = DateTime.Now;
                    }

                    try
                    {
                        elemento.fecha_clave = DateTime.Parse(fecha_clave);
                    }
                    catch
                    {
                        elemento.fecha_clave = DateTime.Now;
                    }

                    try
                    {
                        elemento.dias_clave = int.Parse(dias_clave);
                    }
                    catch
                    {
                        elemento.dias_clave = 0;
                    }

                    elemento.nombre = nombre;
                    elemento.descripcion = descripcion;
                    elemento.password = password;
                    elemento.layout = layout;
                    elemento.layout_acc = layout_acc;
                    elemento.layout_pos = layout_pos;
                    elemento.layout_inv = layout_inv;
                    elemento.layout_fa = layout_fa;
                    elemento.layout_pr = layout_pr;
                    elemento.clave_tarj = clave_tarj;

                    int res = -1;

                    res = Logica.PutUsuario(elemento, iden);

                    return res != -2147483647 ? res.ToString() : L.ERR("LblGENUserNotAuthorized");
                }
                else
                {
                    throw new Exception(L.LBL("LblGENWrongUserSession"));
                }
            }
            catch (Exception ex)
            {
                #region Manejo de Errores (Administrador)

                var metodo = MethodBase.GetCurrentMethod().Name;
                var msgError = string.Format(MssgTrace.Trace_Message_Error, metodo, ex);
                LogGenie.ErrorLogSave(ex.Message, 16, msgError, System.Diagnostics.TraceEventType.Error);

                #endregion

                #region Manejo de Errores (Base de Datos)

                try
                {
                    var xException = new Excepcion
                    {
                        EventID = 0,
                        Priority = 16,
                        Severity = TraceEventType.Error,
                        Title = ex.Message,
                        Timestamp = DateTime.Now,
                        MachineName = Environment.MachineName,
                        AppDomainName = Environment.UserDomainName,
                        ProcessID = string.Empty,
                        ProcessName = Environment.CommandLine,
                        ThreadName = string.Empty,
                        Message = ex.ToString()
                    };

                    Logica logica = new Logica();
                    logica.DataBaseLogError(xException);
                }
                catch
                {
                }

                #endregion

                return "<p class=\"SevenMsgError\"><b>" + L.LBL("LblGENWrongQuery") + ":</b></br> " + L.ERR(ex.Message).Replace("[", "").Replace("]", "") + "</p>";
            }
        }


        #endregion

        #region Boton Aplicar Plantilla a Usuario

        [WebGet]
        [OperationContract]
        public string PutBtnPlantillaUsuario(string Operador, string Plantilla, string U, string N, string D, string I, string LangCode)
        {
            try
            {
                Identidad iden = new Identidad(int.Parse(Enigma.Desencriptar(U)), Enigma.Desencriptar(N), int.Parse(Enigma.Desencriptar(D)), Enigma.Desencriptar(I));

                if ((Seguridad.CargarConfiguracionManagement() == 1) && (Seguridad.VerificarSesion(U, N, 1, D, I)))
                {
                    int id_operador = 0;

                    int id_plantilla = 0;

                    try
                    {
                        id_operador = int.Parse(Operador);
                    }
                    catch
                    {
                        id_operador = 0;
                    }

                    try
                    {
                        id_plantilla = int.Parse(Plantilla);
                    }
                    catch
                    {
                        id_plantilla = 0;
                    }

                    int res = -1;

                    res = Logica.PutBtnPlantillaUsuario(id_operador, id_plantilla, iden);

                    return res != -2147483647 ? res.ToString() : L.ERR("LblGENUserNotAuthorized");
                }
                else
                {
                    throw new Exception(L.LBL("LblGENWrongUserSession"));
                }
            }
            catch (Exception ex)
            {
                #region Manejo de Errores (Administrador)

                var metodo = MethodBase.GetCurrentMethod().Name;
                var msgError = string.Format(MssgTrace.Trace_Message_Error, metodo, ex);
                LogGenie.ErrorLogSave(ex.Message, 16, msgError, System.Diagnostics.TraceEventType.Error);

                #endregion

                #region Manejo de Errores (Base de Datos)

                try
                {
                    var xException = new Excepcion
                    {
                        EventID = 0,
                        Priority = 16,
                        Severity = TraceEventType.Error,
                        Title = ex.Message,
                        Timestamp = DateTime.Now,
                        MachineName = Environment.MachineName,
                        AppDomainName = Environment.UserDomainName,
                        ProcessID = string.Empty,
                        ProcessName = Environment.CommandLine,
                        ThreadName = string.Empty,
                        Message = ex.ToString()
                    };

                    Logica logica = new Logica();
                    logica.DataBaseLogError(xException);
                }
                catch
                {
                }

                #endregion

                return "<p class=\"SevenMsgError\"><b>" + L.LBL("LblGENWrongQuery") + ":</b></br> " + L.ERR(ex.Message).Replace("[", "").Replace("]", "") + "</p>";
            }
        }
        
        #endregion

        #region Usuario Permisos

        [WebGet]
        [OperationContract]
        public string GetPermisosDatosUsuario(string ID_OPER, string Dominio, string U, string N, string D, string I, string LangCode)
        {
            try
            {
                Identidad iden = new Identidad(int.Parse(Enigma.Desencriptar(U)), Enigma.Desencriptar(N), int.Parse(Enigma.Desencriptar(D)), Enigma.Desencriptar(I));

                if ((Seguridad.CargarConfiguracionManagement() == 1) && (Seguridad.VerificarSesion(U, N, 1, D, I)))
                {
                    int id_operador = 0;

                    try
                    {
                        id_operador = int.Parse(ID_OPER);
                    }
                    catch { }

                    Dato elementoD = new Dato();
                    Modulo elementoM = new Modulo();
                    elementoD.id_datos = 0;

                    return Globals.jqGridGenie.DataTableToJQGridJSON(Logica.GetPermisosDatosUsuario(elementoD, elementoM, id_operador, iden));
                }
                else
                {
                    throw new Exception(L.LBL("LblGENWrongUserSession"));
                }
            }
            catch (Exception ex)
            {
                #region Manejo de Errores (Administrador)

                var metodo = MethodBase.GetCurrentMethod().Name;
                var msgError = string.Format(MssgTrace.Trace_Message_Error, metodo, ex);
                LogGenie.ErrorLogSave(ex.Message, 16, msgError, System.Diagnostics.TraceEventType.Error);

                #endregion

                #region Manejo de Errores (Base de Datos)

                try
                {
                    var xException = new Excepcion
                    {
                        EventID = 0,
                        Priority = 16,
                        Severity = TraceEventType.Error,
                        Title = ex.Message,
                        Timestamp = DateTime.Now,
                        MachineName = Environment.MachineName,
                        AppDomainName = Environment.UserDomainName,
                        ProcessID = string.Empty,
                        ProcessName = Environment.CommandLine,
                        ThreadName = string.Empty,
                        Message = ex.ToString()
                    };

                    Logica logica = new Logica();
                    logica.DataBaseLogError(xException);
                }
                catch
                {
                }

                #endregion

                return "<p class=\"SevenMsgError\"><b>" + L.LBL("LblGENWrongQuery") + ":</b></br> " + L.ERR(ex.Message).Replace("[", "").Replace("]", "") + "</p>";
            }
        }

        [WebGet]
        [OperationContract]
        public string PutPermisosDatosUsuario(string id_dato, string id_oper, string Eliminado, string U, string N, string D, string I, string LangCode)
        {
            try
            {
                Identidad iden = new Identidad(int.Parse(Enigma.Desencriptar(U)), Enigma.Desencriptar(N), int.Parse(Enigma.Desencriptar(D)), Enigma.Desencriptar(I));

                if ((Seguridad.CargarConfiguracionManagement() == 1) && (Seguridad.VerificarSesion(U, N, 1, D, I)))
                {
                    Dato elementoD = new Dato();
                    Modulo elementoM = new Modulo();

                    int id_operador=0;

                    int Eli = 0;

                    try
                    {
                        id_operador = int.Parse(id_oper);
                    }
                    catch
                    {}

                    Eli = int.Parse(Eliminado);

                    elementoD.id_datos = int.Parse(id_dato);

                    int res = -1;

                    res = Logica.PutPermisosDatosUsuario(elementoD, id_operador,Eli, iden);

                    return res != -2147483647 ? res.ToString() : L.ERR("LblGENUserNotAuthorized");
                }
                else
                {
                    throw new Exception(L.LBL("LblGENWrongUserSession"));
                }
            }
            catch (Exception ex)
            {
                #region Manejo de Errores (Administrador)

                var metodo = MethodBase.GetCurrentMethod().Name;
                var msgError = string.Format(MssgTrace.Trace_Message_Error, metodo, ex);
                LogGenie.ErrorLogSave(ex.Message, 16, msgError, System.Diagnostics.TraceEventType.Error);

                #endregion

                #region Manejo de Errores (Base de Datos)

                try
                {
                    var xException = new Excepcion
                    {
                        EventID = 0,
                        Priority = 16,
                        Severity = TraceEventType.Error,
                        Title = ex.Message,
                        Timestamp = DateTime.Now,
                        MachineName = Environment.MachineName,
                        AppDomainName = Environment.UserDomainName,
                        ProcessID = string.Empty,
                        ProcessName = Environment.CommandLine,
                        ThreadName = string.Empty,
                        Message = ex.ToString()
                    };

                    Logica logica = new Logica();
                    logica.DataBaseLogError(xException);
                }
                catch
                {
                }

                #endregion

                return "<p class=\"SevenMsgError\"><b>" + L.LBL("LblGENWrongQuery") + ":</b></br> " + L.ERR(ex.Message).Replace("[", "").Replace("]", "") + "</p>";
            }
        }

        [WebGet]
        [OperationContract]
        public string GetPermisosOpcionesUsuario(string Opcion, string Id, string Operador, string Dominio, string U, string N, string D, string I, string LangCode)
        {
            try
            {
                Identidad iden = new Identidad(int.Parse(Enigma.Desencriptar(U)), Enigma.Desencriptar(N), int.Parse(Enigma.Desencriptar(D)), Enigma.Desencriptar(I));

                if ((Seguridad.CargarConfiguracionManagement() == 1) && (Seguridad.VerificarSesion(U, N, 1, D, I)))
                {
                    int id_operador = 0;
                    int opcion = 0;
                    int multi_id = 0;
                    bool Eliminados = false;

                    try
                    {
                        id_operador = int.Parse(Operador);
                    }
                    catch { }

                    try
                    {
                        opcion = int.Parse(Opcion);
                    }
                    catch { }

                    try
                    {
                        multi_id = int.Parse(Id);
                    }
                    catch { }

                    return Globals.jqGridGenie.DataTableToJQGridJSON(Logica.GetPermisosOpcionesUsuario(multi_id, opcion, id_operador, Eliminados, iden));

                }
                else
                {
                    throw new Exception(L.LBL("LblGENWrongUserSession"));
                }
            }
            catch (Exception ex)
            {
                #region Manejo de Errores (Administrador)

                var metodo = MethodBase.GetCurrentMethod().Name;
                var msgError = string.Format(MssgTrace.Trace_Message_Error, metodo, ex);
                LogGenie.ErrorLogSave(ex.Message, 16, msgError, System.Diagnostics.TraceEventType.Error);

                #endregion

                #region Manejo de Errores (Base de Datos)

                try
                {
                    var xException = new Excepcion
                    {
                        EventID = 0,
                        Priority = 16,
                        Severity = TraceEventType.Error,
                        Title = ex.Message,
                        Timestamp = DateTime.Now,
                        MachineName = Environment.MachineName,
                        AppDomainName = Environment.UserDomainName,
                        ProcessID = string.Empty,
                        ProcessName = Environment.CommandLine,
                        ThreadName = string.Empty,
                        Message = ex.ToString()
                    };

                    Logica logica = new Logica();
                    logica.DataBaseLogError(xException);
                }
                catch
                {
                }

                #endregion

                return "<p class=\"SevenMsgError\"><b>" + L.LBL("LblGENWrongQuery") + ":</b></br> " + L.ERR(ex.Message).Replace("[", "").Replace("]", "") + "</p>";
            }
        }

        [WebGet]
        [OperationContract]
        public string PutPermisosOpcionesUsuario(string Opcion, string Id, string Operador, string Eliminado, string U, string N, string D, string I, string LangCode)
        {
            try
            {
                Identidad iden = new Identidad(int.Parse(Enigma.Desencriptar(U)), Enigma.Desencriptar(N), int.Parse(Enigma.Desencriptar(D)), Enigma.Desencriptar(I));

                if ((Seguridad.CargarConfiguracionManagement() == 1) && (Seguridad.VerificarSesion(U, N, 1, D, I)))
                {
                    int id_operador = 0;
                    int opcion = 0;
                    int multi_id = 0;

                    int Eli = 0;

                    try
                    {
                        id_operador = int.Parse(Operador);
                    }
                    catch
                    { }

                    try
                    {
                        opcion = int.Parse(Opcion);
                    }
                    catch { }

                    try
                    {
                        multi_id = int.Parse(Id);
                    }
                    catch { }

                    Eli = int.Parse(Eliminado);

                    int res = -1;

                    res = Logica.PutPermisosOpcionesUsuario(multi_id, opcion, id_operador, Eli, iden);

                    return res != -2147483647 ? res.ToString() : L.ERR("LblGENUserNotAuthorized");
                }
                else
                {
                    throw new Exception(L.LBL("LblGENWrongUserSession"));
                }
            }
            catch (Exception ex)
            {
                #region Manejo de Errores (Administrador)

                var metodo = MethodBase.GetCurrentMethod().Name;
                var msgError = string.Format(MssgTrace.Trace_Message_Error, metodo, ex);
                LogGenie.ErrorLogSave(ex.Message, 16, msgError, System.Diagnostics.TraceEventType.Error);

                #endregion

                #region Manejo de Errores (Base de Datos)

                try
                {
                    var xException = new Excepcion
                    {
                        EventID = 0,
                        Priority = 16,
                        Severity = TraceEventType.Error,
                        Title = ex.Message,
                        Timestamp = DateTime.Now,
                        MachineName = Environment.MachineName,
                        AppDomainName = Environment.UserDomainName,
                        ProcessID = string.Empty,
                        ProcessName = Environment.CommandLine,
                        ThreadName = string.Empty,
                        Message = ex.ToString()
                    };

                    Logica logica = new Logica();
                    logica.DataBaseLogError(xException);
                }
                catch
                {
                }

                #endregion

                return "<p class=\"SevenMsgError\"><b>" + L.LBL("LblGENWrongQuery") + ":</b></br> " + L.ERR(ex.Message).Replace("[", "").Replace("]", "") + "</p>";
            }
        }

        #endregion

        #region Plantillas

        [WebGet]
        [OperationContract]
        public string GetPlantillas(string Eliminado, string Dominio, string U, string N, string D, string I, string LangCode)
        {
            try
            {
                Identidad iden = new Identidad(int.Parse(Enigma.Desencriptar(U)), Enigma.Desencriptar(N), int.Parse(Enigma.Desencriptar(D)), Enigma.Desencriptar(I));

                if ((Seguridad.CargarConfiguracionManagement() == 1) && (Seguridad.VerificarSesion(U, N, 1, D, I)))
                {
                    bool Eliminados = false;
                    try
                    {
                        Eliminados = int.Parse(Eliminado) == 0 ? false : true;
                    }
                    catch { }

                    Plantilla elemento = new Plantilla();
                    elemento.id_tip_oper = 0;

                    return Globals.jqGridGenie.DataTableToJQGridJSON(Logica.GetPlantillas(elemento, Eliminados, iden));
                }
                else
                {
                    throw new Exception(L.LBL("LblGENWrongUserSession"));
                }
            }
            catch (Exception ex)
            {
                #region Manejo de Errores (Administrador)

                var metodo = MethodBase.GetCurrentMethod().Name;
                var msgError = string.Format(MssgTrace.Trace_Message_Error, metodo, ex);
                LogGenie.ErrorLogSave(ex.Message, 16, msgError, System.Diagnostics.TraceEventType.Error);

                #endregion

                #region Manejo de Errores (Base de Datos)

                try
                {
                    var xException = new Excepcion
                    {
                        EventID = 0,
                        Priority = 16,
                        Severity = TraceEventType.Error,
                        Title = ex.Message,
                        Timestamp = DateTime.Now,
                        MachineName = Environment.MachineName,
                        AppDomainName = Environment.UserDomainName,
                        ProcessID = string.Empty,
                        ProcessName = Environment.CommandLine,
                        ThreadName = string.Empty,
                        Message = ex.ToString()
                    };

                    Logica logica = new Logica();
                    logica.DataBaseLogError(xException);
                }
                catch
                {
                }

                #endregion

                return "<p class=\"SevenMsgError\"><b>" + L.LBL("LblGENWrongQuery") + ":</b></br> " + L.ERR(ex.Message).Replace("[", "").Replace("]", "") + "</p>";
            }
        }

        [WebGet]
        [OperationContract]
        public string PutPlantillas(string id_tip_oper, string nombre, string descripcion, string Eliminado, string U, string N, string D, string I, string LangCode)
        {
            try
            {
                Identidad iden = new Identidad(int.Parse(Enigma.Desencriptar(U)), Enigma.Desencriptar(N), int.Parse(Enigma.Desencriptar(D)), Enigma.Desencriptar(I));

                if ((Seguridad.CargarConfiguracionManagement() == 1) && (Seguridad.VerificarSesion(U, N, 1, D, I)))
                {
                    Plantilla elemento = new Plantilla();
                    try
                    {
                        elemento.id_tip_oper = int.Parse(id_tip_oper);
                    }
                    catch
                    {
                        elemento.id_tip_oper = 0;
                    }
                    elemento.nombre = nombre;
                    elemento.descripcion = descripcion;


                    elemento.eliminado = int.Parse(Eliminado);

                    int res = -1;

                    res = Logica.PutPlantillas(elemento, iden);

                    return res != -2147483647 ? res.ToString() : L.ERR("LblGENUserNotAuthorized");
                }
                else
                {
                    throw new Exception(L.LBL("LblGENWrongUserSession"));
                }
            }
            catch (Exception ex)
            {
                #region Manejo de Errores (Administrador)

                var metodo = MethodBase.GetCurrentMethod().Name;
                var msgError = string.Format(MssgTrace.Trace_Message_Error, metodo, ex);
                LogGenie.ErrorLogSave(ex.Message, 16, msgError, System.Diagnostics.TraceEventType.Error);

                #endregion

                #region Manejo de Errores (Base de Datos)

                try
                {
                    var xException = new Excepcion
                    {
                        EventID = 0,
                        Priority = 16,
                        Severity = TraceEventType.Error,
                        Title = ex.Message,
                        Timestamp = DateTime.Now,
                        MachineName = Environment.MachineName,
                        AppDomainName = Environment.UserDomainName,
                        ProcessID = string.Empty,
                        ProcessName = Environment.CommandLine,
                        ThreadName = string.Empty,
                        Message = ex.ToString()
                    };

                    Logica logica = new Logica();
                    logica.DataBaseLogError(xException);
                }
                catch
                {
                }

                #endregion

                return "<p class=\"SevenMsgError\"><b>" + L.LBL("LblGENWrongQuery") + ":</b></br> " + L.ERR(ex.Message).Replace("[", "").Replace("]", "") + "</p>";
            }
        }


        #endregion

        #region Plantillas Permisos

        [WebGet]
        [OperationContract]
        public string GetPermisosDatosPlantilla(string ID_OPER, string Dominio, string U, string N, string D, string I, string LangCode)
        {
            try
            {
                Identidad iden = new Identidad(int.Parse(Enigma.Desencriptar(U)), Enigma.Desencriptar(N), int.Parse(Enigma.Desencriptar(D)), Enigma.Desencriptar(I));

                if ((Seguridad.CargarConfiguracionManagement() == 1) && (Seguridad.VerificarSesion(U, N, 1, D, I)))
                {
                    int id_operador = 0;

                    try
                    {
                        id_operador = int.Parse(ID_OPER);
                    }
                    catch { }

                    return Globals.jqGridGenie.DataTableToJQGridJSON(Logica.GetPermisosDatosPlantilla(id_operador, iden));
                }
                else
                {
                    throw new Exception(L.LBL("LblGENWrongUserSession"));
                }
            }
            catch (Exception ex)
            {
                #region Manejo de Errores (Administrador)

                var metodo = MethodBase.GetCurrentMethod().Name;
                var msgError = string.Format(MssgTrace.Trace_Message_Error, metodo, ex);
                LogGenie.ErrorLogSave(ex.Message, 16, msgError, System.Diagnostics.TraceEventType.Error);

                #endregion

                #region Manejo de Errores (Base de Datos)

                try
                {
                    var xException = new Excepcion
                    {
                        EventID = 0,
                        Priority = 16,
                        Severity = TraceEventType.Error,
                        Title = ex.Message,
                        Timestamp = DateTime.Now,
                        MachineName = Environment.MachineName,
                        AppDomainName = Environment.UserDomainName,
                        ProcessID = string.Empty,
                        ProcessName = Environment.CommandLine,
                        ThreadName = string.Empty,
                        Message = ex.ToString()
                    };

                    Logica logica = new Logica();
                    logica.DataBaseLogError(xException);
                }
                catch
                {
                }

                #endregion

                return "<p class=\"SevenMsgError\"><b>" + L.LBL("LblGENWrongQuery") + ":</b></br> " + L.ERR(ex.Message).Replace("[", "").Replace("]", "") + "</p>";
            }
        }

        [WebGet]
        [OperationContract]
        public string PutPermisosDatosPlantilla(string id_dato, string id_oper, string Eliminado, string U, string N, string D, string I, string LangCode)
        {
            try
            {
                Identidad iden = new Identidad(int.Parse(Enigma.Desencriptar(U)), Enigma.Desencriptar(N), int.Parse(Enigma.Desencriptar(D)), Enigma.Desencriptar(I));

                if ((Seguridad.CargarConfiguracionManagement() == 1) && (Seguridad.VerificarSesion(U, N, 1, D, I)))
                {
                    Dato elementoD = new Dato();
                    Modulo elementoM = new Modulo();

                    int id_operador = 0;

                    int Eli = 0;

                    try
                    {
                        id_operador = int.Parse(id_oper);
                    }
                    catch
                    { }

                    Eli = int.Parse(Eliminado);

                    elementoD.id_datos = int.Parse(id_dato);

                    int res = -1;

                    res = Logica.PutPermisosDatosPlantilla(elementoD, id_operador, Eli, iden);

                    return res != -2147483647 ? res.ToString() : L.ERR("LblGENUserNotAuthorized");
                }
                else
                {
                    throw new Exception(L.LBL("LblGENWrongUserSession"));
                }
            }
            catch (Exception ex)
            {
                #region Manejo de Errores (Administrador)

                var metodo = MethodBase.GetCurrentMethod().Name;
                var msgError = string.Format(MssgTrace.Trace_Message_Error, metodo, ex);
                LogGenie.ErrorLogSave(ex.Message, 16, msgError, System.Diagnostics.TraceEventType.Error);

                #endregion

                #region Manejo de Errores (Base de Datos)

                try
                {
                    var xException = new Excepcion
                    {
                        EventID = 0,
                        Priority = 16,
                        Severity = TraceEventType.Error,
                        Title = ex.Message,
                        Timestamp = DateTime.Now,
                        MachineName = Environment.MachineName,
                        AppDomainName = Environment.UserDomainName,
                        ProcessID = string.Empty,
                        ProcessName = Environment.CommandLine,
                        ThreadName = string.Empty,
                        Message = ex.ToString()
                    };

                    Logica logica = new Logica();
                    logica.DataBaseLogError(xException);
                }
                catch
                {
                }

                #endregion

                return "<p class=\"SevenMsgError\"><b>" + L.LBL("LblGENWrongQuery") + ":</b></br> " + L.ERR(ex.Message).Replace("[", "").Replace("]", "") + "</p>";
            }
        }

        [WebGet]
        [OperationContract]
        public string GetPermisosOpcionesPlantilla(string Opcion, string Id, string Operador, string Dominio, string U, string N, string D, string I, string LangCode)
        {
            try
            {
                Identidad iden = new Identidad(int.Parse(Enigma.Desencriptar(U)), Enigma.Desencriptar(N), int.Parse(Enigma.Desencriptar(D)), Enigma.Desencriptar(I));

                if ((Seguridad.CargarConfiguracionManagement() == 1) && (Seguridad.VerificarSesion(U, N, 1, D, I)))
                {
                    int id_operador = 0;
                    int opcion = 0;
                    int multi_id = 0;
                    bool Eliminados = false;

                    try
                    {
                        id_operador = int.Parse(Operador);
                    }
                    catch { }

                    try
                    {
                        opcion = int.Parse(Opcion);
                    }
                    catch { }

                    try
                    {
                        multi_id = int.Parse(Id);
                    }
                    catch { }

                    return Globals.jqGridGenie.DataTableToJQGridJSON(Logica.GetPermisosOpcionesPlantilla(multi_id, opcion, id_operador, Eliminados, iden));

                }
                else
                {
                    throw new Exception(L.LBL("LblGENWrongUserSession"));
                }
            }
            catch (Exception ex)
            {
                #region Manejo de Errores (Administrador)

                var metodo = MethodBase.GetCurrentMethod().Name;
                var msgError = string.Format(MssgTrace.Trace_Message_Error, metodo, ex);
                LogGenie.ErrorLogSave(ex.Message, 16, msgError, System.Diagnostics.TraceEventType.Error);

                #endregion

                #region Manejo de Errores (Base de Datos)

                try
                {
                    var xException = new Excepcion
                    {
                        EventID = 0,
                        Priority = 16,
                        Severity = TraceEventType.Error,
                        Title = ex.Message,
                        Timestamp = DateTime.Now,
                        MachineName = Environment.MachineName,
                        AppDomainName = Environment.UserDomainName,
                        ProcessID = string.Empty,
                        ProcessName = Environment.CommandLine,
                        ThreadName = string.Empty,
                        Message = ex.ToString()
                    };

                    Logica logica = new Logica();
                    logica.DataBaseLogError(xException);
                }
                catch
                {
                }

                #endregion

                return "<p class=\"SevenMsgError\"><b>" + L.LBL("LblGENWrongQuery") + ":</b></br> " + L.ERR(ex.Message).Replace("[", "").Replace("]", "") + "</p>";
            }
        }

        [WebGet]
        [OperationContract]
        public string PutPermisosOpcionesPlantilla(string Opcion, string Id, string Operador, string Eliminado, string U, string N, string D, string I, string LangCode)
        {
            try
            {
                Identidad iden = new Identidad(int.Parse(Enigma.Desencriptar(U)), Enigma.Desencriptar(N), int.Parse(Enigma.Desencriptar(D)), Enigma.Desencriptar(I));

                if ((Seguridad.CargarConfiguracionManagement() == 1) && (Seguridad.VerificarSesion(U, N, 1, D, I)))
                {
                    int id_operador = 0;
                    int opcion = 0;
                    int multi_id = 0;

                    int Eli = 0;

                    try
                    {
                        id_operador = int.Parse(Operador);
                    }
                    catch
                    { }

                    try
                    {
                        opcion = int.Parse(Opcion);
                    }
                    catch { }

                    try
                    {
                        multi_id = int.Parse(Id);
                    }
                    catch { }

                    Eli = int.Parse(Eliminado);

                    int res = -1;

                    res = Logica.PutPermisosOpcionesPlantilla(multi_id, opcion, id_operador, Eli, iden);

                    return res != -2147483647 ? res.ToString() : L.ERR("LblGENUserNotAuthorized");
                }
                else
                {
                    throw new Exception(L.LBL("LblGENWrongUserSession"));
                }
            }
            catch (Exception ex)
            {
                #region Manejo de Errores (Administrador)

                var metodo = MethodBase.GetCurrentMethod().Name;
                var msgError = string.Format(MssgTrace.Trace_Message_Error, metodo, ex);
                LogGenie.ErrorLogSave(ex.Message, 16, msgError, System.Diagnostics.TraceEventType.Error);

                #endregion

                #region Manejo de Errores (Base de Datos)

                try
                {
                    var xException = new Excepcion
                    {
                        EventID = 0,
                        Priority = 16,
                        Severity = TraceEventType.Error,
                        Title = ex.Message,
                        Timestamp = DateTime.Now,
                        MachineName = Environment.MachineName,
                        AppDomainName = Environment.UserDomainName,
                        ProcessID = string.Empty,
                        ProcessName = Environment.CommandLine,
                        ThreadName = string.Empty,
                        Message = ex.ToString()
                    };

                    Logica logica = new Logica();
                    logica.DataBaseLogError(xException);
                }
                catch
                {
                }

                #endregion

                return "<p class=\"SevenMsgError\"><b>" + L.LBL("LblGENWrongQuery") + ":</b></br> " + L.ERR(ex.Message).Replace("[", "").Replace("]", "") + "</p>";
            }
        }

        #endregion

        #region Impresión Directa de Documentos (IDD)

        [WebGet]
        [OperationContract]
        public string GetImpresoras(string U, string N, string D, string I, string LangCode)
        {
            try
            {
                Identidad iden = new Identidad(int.Parse(Enigma.Desencriptar(U)), Enigma.Desencriptar(N), int.Parse(Enigma.Desencriptar(D)), Enigma.Desencriptar(I));

                if ((Seguridad.CargarConfiguracionManagement() == 1) && (Seguridad.VerificarSesion(U, N, 1, D, I)))
                {
                    return Globals.jqGridGenie.DataTableToJQGridJSON(Logica.GetImpresoras(iden))
                        .Replace("LblGENFactura", L.LBL("LblGENFactura"))
                        .Replace("LblGENRecibo", L.LBL("LblGENRecibo"))
                        .Replace("LblGENCheque", L.LBL("LblGENCheque"))
                        .Replace("LblREPPreimpresionFolio", L.REP("LblREPPreimpresionFolio"))
                        .Replace("LblFDKPCIERFacturasEmpresas", L.LBL("LblFDKPCIERFacturasEmpresas"))
                        .Replace("LblFDKProforma", L.LBL("LblFDKProforma"))
                        .Replace("LblREPDepAdelEF", L.REP("LblREPDepAdelEF"))
                        .Replace("LblREPDepAdelTarj", L.REP("LblREPDepAdelTarj"))
                        .Replace("OFCanje", L.TIT("OFCanje"))
                        .Replace("Prepagos", L.TIT("Prepagos"))
                        .Replace("Notas", L.TIT("Notas"))
                        .Replace("Reservas", L.TIT("Reservas"))
                        .Replace("RoomingList", L.TIT("RoomingList"))
                        .Replace("TarjetaRegistro", L.TIT("TarjetaRegistro"))
                        .Replace("LblGENDocumentos", L.LBL("LblGENDocumentos"));
                }
                else
                {
                    throw new Exception(L.LBL("LblGENWrongUserSession"));
                }
            }
            catch (Exception ex)
            {
                #region Manejo de Errores (Administrador)

                var metodo = MethodBase.GetCurrentMethod().Name;
                var msgError = string.Format(MssgTrace.Trace_Message_Error, metodo, ex);
                LogGenie.ErrorLogSave(ex.Message, 16, msgError, System.Diagnostics.TraceEventType.Error);

                #endregion

                #region Manejo de Errores (Base de Datos)

                try
                {
                    var xException = new Excepcion
                    {
                        EventID = 0,
                        Priority = 16,
                        Severity = TraceEventType.Error,
                        Title = ex.Message,
                        Timestamp = DateTime.Now,
                        MachineName = Environment.MachineName,
                        AppDomainName = Environment.UserDomainName,
                        ProcessID = string.Empty,
                        ProcessName = Environment.CommandLine,
                        ThreadName = string.Empty,
                        Message = ex.ToString()
                    };

                    Logica logica = new Logica();
                    logica.DataBaseLogError(xException);
                }
                catch
                {
                }

                #endregion

                return "<p class=\"SevenMsgError\"><b>" + L.LBL("LblGENWrongQuery") + ":</b></br> " + L.ERR(ex.Message).Replace("[", "").Replace("]", "") + "</p>";
            }
        }

        [WebGet]
        [OperationContract]
        public string PutImpresoras(string id_repo, string descripcion, string tipo_impresora, string id_papel, string Eliminado
            , string U, string N, string D, string I, string LangCode)
        {
            try
            {
                Identidad iden = new Identidad(int.Parse(Enigma.Desencriptar(U)), Enigma.Desencriptar(N), int.Parse(Enigma.Desencriptar(D)), Enigma.Desencriptar(I));

                if ((Seguridad.CargarConfiguracionManagement() == 1) && (Seguridad.VerificarSesion(U, N, 1, D, I)))
                {
                    Impresora elemento = new Impresora();
                    try
                    {
                        elemento.id_repo = int.Parse(id_repo);
                    }
                    catch
                    {
                        elemento.id_repo = 0;
                    }
                    elemento.descripcion = descripcion;
                    elemento.tipo_impresora = int.Parse(tipo_impresora);
                    elemento.id_papel = int.Parse(id_papel);

                    elemento.eliminado = int.Parse(Eliminado) == 1 ? true : false;

                    int res = -1;

                    res = Logica.PutImpresoras(elemento, iden);

                    return res != -2147483647 ? res.ToString() : L.ERR("LblGENUserNotAuthorized");
                }
                else
                {
                    throw new Exception(L.LBL("LblGENWrongUserSession"));
                }
            }
            catch (Exception ex)
            {
                #region Manejo de Errores (Administrador)

                var metodo = MethodBase.GetCurrentMethod().Name;
                var msgError = string.Format(MssgTrace.Trace_Message_Error, metodo, ex);
                LogGenie.ErrorLogSave(ex.Message, 16, msgError, System.Diagnostics.TraceEventType.Error);

                #endregion

                #region Manejo de Errores (Base de Datos)

                try
                {
                    var xException = new Excepcion
                    {
                        EventID = 0,
                        Priority = 16,
                        Severity = TraceEventType.Error,
                        Title = ex.Message,
                        Timestamp = DateTime.Now,
                        MachineName = Environment.MachineName,
                        AppDomainName = Environment.UserDomainName,
                        ProcessID = string.Empty,
                        ProcessName = Environment.CommandLine,
                        ThreadName = string.Empty,
                        Message = ex.ToString()
                    };

                    Logica logica = new Logica();
                    logica.DataBaseLogError(xException);
                }
                catch
                {
                }

                #endregion

                return "<p class=\"SevenMsgError\"><b>" + L.LBL("LblGENWrongQuery") + ":</b></br> " + L.ERR(ex.Message).Replace("[", "").Replace("]", "") + "</p>";
            }
        }

        #endregion
    }
}

